@@ -27,7 +27,7 @@ from dagster._core.origin import (
     PipelinePythonOrigin,
     get_python_environment_entry_point,
 )
-from dagster._core.storage.pipeline_run import PipelineRun
+from dagster._core.storage.pipeline_run import DagsterRun
 from dagster._core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster._core.utils import coerce_valid_log_level
 from dagster._grpc import DagsterGrpcClient, DagsterGrpcServer
@@ -95,7 +95,7 @@ def _execute_run_command_body(
             instance, pipeline_run_id
         )
 
-    pipeline_run: PipelineRun = check.not_none(
+    pipeline_run: DagsterRun = check.not_none(
         instance.get_run_by_id(pipeline_run_id),
         "Pipeline run with id '{}' not found for run execution.".format(pipeline_run_id),
     )
@@ -359,7 +359,7 @@ def execute_step_command(input_json, compressed_input_json):
 
 
 def _execute_step_command_body(
-    args: ExecuteStepArgs, instance: DagsterInstance, pipeline_run: PipelineRun
+    args: ExecuteStepArgs, instance: DagsterInstance, pipeline_run: DagsterRun
 ):
     single_step_key = (
         args.step_keys_to_execute[0]
@@ -369,7 +369,7 @@ def _execute_step_command_body(
     try:
         check.inst(
             pipeline_run,
-            PipelineRun,
+            DagsterRun,
             "Pipeline run with id '{}' not found for step execution".format(args.pipeline_run_id),
         )
         check.inst(
