@@ -122,8 +122,14 @@ class AssetReconciliationCursor(NamedTuple):
             | requested_non_partitioned_root_assets
         )
 
+        if latest_storage_id and self.latest_storage_id:
+            check.invariant(
+                latest_storage_id >= self.latest_storage_id,
+                "Latest storage ID should be >= previous latest storage ID",
+            )
+
         return AssetReconciliationCursor(
-            latest_storage_id=latest_storage_id,
+            latest_storage_id=latest_storage_id or self.latest_storage_id,
             materialized_or_requested_root_asset_keys=result_materialized_or_requested_root_asset_keys,
             materialized_or_requested_root_partitions_by_asset_key=result_materialized_or_requested_root_partitions_by_asset_key,
         )
@@ -743,10 +749,14 @@ def build_asset_reconciliation_sensor(
     "reconcile" them.
 
     An asset is considered "unreconciled" if any of:
+
     - This sensor has never tried to materialize it and it has never been materialized.
+
     - Any of its parents have been materialized more recently than it has.
+
     - Any of its parents are unreconciled.
-    - It is not currently up to date with respect to its FreshnessPolicy
+
+    - It is not currently up to date with respect to its freshness policy.
 
     The sensor won't try to reconcile any assets before their parents are reconciled. When multiple
     FreshnessPolicies require data from the same upstream assets, this sensor will attempt to
@@ -802,9 +812,9 @@ def build_asset_reconciliation_sensor(
 
         .. code-block:: python
 
-            a       b
-             \     /
-                c
+            a     b
+             \   /
+               c
 
         and create the sensor:
 
@@ -826,13 +836,16 @@ def build_asset_reconciliation_sensor(
               by ``c``. Materializing ``c`` in the same run as those assets will satisfy its
               required data constraint, and so the sensor will kick off a run for ``c`` alongside
               whichever upstream assets did not have up-to-date data.
-            * On the next tick, the sensor will see that a run is currently planned which will satisfy that constraint, so no
-              runs will be kicked off.
+            * On the next tick, the sensor will see that a run is currently planned which will
+              satisfy that constraint, so no runs will be kicked off.
+            * Once that run completes, a new materialization event will exist for ``c``, which will
+              incorporate all of the required data, so no new runs will be kicked off until the
+              following day.
 
 
     """
     check_valid_name(name)
-    check.opt_dict_param(run_tags, "run_tags", key_type=str, value_type=str)
+    check.opt_mapping_param(run_tags, "run_tags", key_type=str, value_type=str)
 
     def sensor_fn(context):
         cursor = (
