@@ -34,11 +34,12 @@ from dagster._core.types.dagster_type import (
 
 from .dependency import (
     DependencyStructure,
+    GraphNode,
     IDependencyDefinition,
     Node,
     NodeHandle,
+    NodeInput,
     NodeInvocation,
-    SolidInputHandle,
 )
 from .hook_definition import HookDefinition
 from .input import FanInInputPointer, InputDefinition, InputMapping, InputPointer
@@ -59,8 +60,8 @@ if TYPE_CHECKING:
     from .composition import PendingNodeInvocation
     from .executor_definition import ExecutorDefinition
     from .job_definition import JobDefinition
+    from .op_definition import OpDefinition
     from .partition import PartitionedConfig, PartitionsDefinition
-    from .solid_definition import SolidDefinition
 
 
 def _check_node_defs_arg(
@@ -90,28 +91,28 @@ def _check_node_defs_arg(
 
 
 def _create_adjacency_lists(
-    solids: Sequence[Node],
+    nodes: Sequence[Node],
     dep_structure: DependencyStructure,
 ) -> Tuple[Mapping[str, Set[str]], Mapping[str, Set[str]]]:
-    visit_dict = {s.name: False for s in solids}
-    forward_edges: Dict[str, Set[str]] = {s.name: set() for s in solids}
-    backward_edges: Dict[str, Set[str]] = {s.name: set() for s in solids}
+    visit_dict = {s.name: False for s in nodes}
+    forward_edges: Dict[str, Set[str]] = {s.name: set() for s in nodes}
+    backward_edges: Dict[str, Set[str]] = {s.name: set() for s in nodes}
 
-    def visit(solid_name: str) -> None:
-        if visit_dict[solid_name]:
+    def visit(node_name: str) -> None:
+        if visit_dict[node_name]:
             return
 
-        visit_dict[solid_name] = True
+        visit_dict[node_name] = True
 
-        for output_handle in dep_structure.all_upstream_outputs_from_solid(solid_name):
-            forward_node = output_handle.solid.name
-            backward_node = solid_name
+        for node_output in dep_structure.all_upstream_outputs_from_node(node_name):
+            forward_node = node_output.node.name
+            backward_node = node_name
             if forward_node in forward_edges:
                 forward_edges[forward_node].add(backward_node)
                 backward_edges[backward_node].add(forward_node)
                 visit(forward_node)
 
-    for s in solids:
+    for s in nodes:
         visit(s.name)
 
     return (forward_edges, backward_edges)
@@ -179,7 +180,7 @@ class GraphDefinition(NodeDefinition):
     _input_mappings: Sequence[InputMapping]
     _output_mappings: Sequence[OutputMapping]
     _config_mapping: Optional[ConfigMapping]
-    _solids_in_topological_order: Sequence[Node]
+    _nodes_in_topological_order: Sequence[Node]
 
     def __init__(
         self,
@@ -233,10 +234,10 @@ class GraphDefinition(NodeDefinition):
 
         # must happen after base class construction as properties are assumed to be there
         # eager computation to detect cycles
-        self._solids_in_topological_order = self._get_solids_in_topological_order()
+        self._nodes_in_topological_order = self._get_nodes_in_topological_order()
         self._dagster_type_dict = construct_dagster_type_dictionary([self])
 
-    def _get_solids_in_topological_order(self) -> Sequence[Node]:
+    def _get_nodes_in_topological_order(self) -> Sequence[Node]:
 
         _forward_edges, backward_edges = _create_adjacency_lists(
             self.solids, self.dependency_structure
@@ -258,7 +259,7 @@ class GraphDefinition(NodeDefinition):
             for input_def in node.definition.get_inputs_must_be_resolved_top_level(
                 asset_layer, cur_handle
             ):
-                if self.dependency_structure.has_deps(SolidInputHandle(node, input_def)):
+                if self.dependency_structure.has_deps(NodeInput(node, input_def)):
                     continue
                 elif not node.container_maps_input(input_def.name):
                     raise DagsterInvalidDefinitionError(
@@ -296,7 +297,7 @@ class GraphDefinition(NodeDefinition):
 
     @property
     def solids_in_topological_order(self) -> Sequence[Node]:
-        return self._solids_in_topological_order
+        return self._nodes_in_topological_order
 
     def has_solid_named(self, name: str) -> bool:
         check.str_param(name, "name")
@@ -334,7 +335,7 @@ class GraphDefinition(NodeDefinition):
         for outer_node_def in self._node_defs:
             yield from outer_node_def.iterate_node_defs()
 
-    def iterate_solid_defs(self) -> Iterator["SolidDefinition"]:
+    def iterate_solid_defs(self) -> Iterator["OpDefinition"]:
         for outer_node_def in self._node_defs:
             yield from outer_node_def.iterate_solid_defs()
 
@@ -343,7 +344,7 @@ class GraphDefinition(NodeDefinition):
     ) -> Iterator[NodeHandle]:
         for node in self.node_dict.values():
             cur_node_handle = NodeHandle(node.name, parent_node_handle)
-            if node.is_graph:
+            if isinstance(node, GraphNode):
                 graph_def = node.definition.ensure_graph_def()
                 yield from graph_def.iterate_node_handles(cur_node_handle)
             yield cur_node_handle
@@ -419,7 +420,7 @@ class GraphDefinition(NodeDefinition):
             NodeHandle(mapped_solid.name, handle),  # type: ignore
         )
 
-    def resolve_output_to_origin_op_def(self, output_name: str) -> "SolidDefinition":
+    def resolve_output_to_origin_op_def(self, output_name: str) -> "OpDefinition":
         mapping = self.get_output_mapping(output_name)
         check.invariant(mapping, "Can only resolve outputs for valid output names")
         return self.solid_named(
@@ -519,7 +520,7 @@ class GraphDefinition(NodeDefinition):
         description: Optional[str] = None,
         resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
         config: Optional[Union[ConfigMapping, Mapping[str, object], "PartitionedConfig"]] = None,
-        tags: Optional[Mapping[str, object]] = None,
+        tags: Optional[Mapping[str, str]] = None,
         metadata: Optional[Mapping[str, RawMetadataValue]] = None,
         logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
         executor_def: Optional["ExecutorDefinition"] = None,
@@ -664,7 +665,6 @@ class GraphDefinition(NodeDefinition):
             :py:class:`~dagster.ExecuteInProcessResult`
         """
         from dagster._core.execution.build_resources import wrap_resources_for_execution
-        from dagster._core.execution.execute_in_process import core_execute_in_process
         from dagster._core.instance import DagsterInstance
 
         from .executor_definition import execute_in_process_executor
@@ -687,11 +687,9 @@ class GraphDefinition(NodeDefinition):
         run_config = run_config if run_config is not None else {}
         op_selection = check.opt_sequence_param(op_selection, "op_selection", str)
 
-        return core_execute_in_process(
-            ephemeral_pipeline=ephemeral_job,
+        return ephemeral_job.execute_in_process(
             run_config=run_config,
             instance=instance,
-            output_capturing_enabled=True,
             raise_on_error=raise_on_error,
             run_id=run_id,
         )
@@ -843,17 +841,17 @@ def _validate_in_mappings(
             )
 
         target_input_def = target_node.input_def_named(mapping.maps_to.input_name)
-        solid_input_handle = SolidInputHandle(target_node, target_input_def)
+        node_input = NodeInput(target_node, target_input_def)
 
         if mapping.maps_to_fan_in:
             maps_to = cast(FanInInputPointer, mapping.maps_to)
-            if not dependency_structure.has_fan_in_deps(solid_input_handle):
+            if not dependency_structure.has_fan_in_deps(node_input):
                 raise DagsterInvalidDefinitionError(
                     f"In {class_name} '{name}' input mapping target "
                     f'"{maps_to.node_name}.{maps_to.input_name}" (index {maps_to.fan_in_index} of fan-in) '
                     f"is not a MultiDependencyDefinition."
                 )
-            inner_deps = dependency_structure.get_fan_in_deps(solid_input_handle)
+            inner_deps = dependency_structure.get_fan_in_deps(node_input)
             if (maps_to.fan_in_index >= len(inner_deps)) or (
                 inner_deps[maps_to.fan_in_index] is not MappedInputPlaceholder
             ):
@@ -867,7 +865,7 @@ def _validate_in_mappings(
                 target_input_def.dagster_type.get_inner_type_for_fan_in()
             )
         else:
-            if dependency_structure.has_deps(solid_input_handle):
+            if dependency_structure.has_deps(node_input):
                 raise DagsterInvalidDefinitionError(
                     f"In {class_name} '{name}' input mapping target "
                     f'"{mapping.maps_to.node_name}.{mapping.maps_to.input_name}" '
@@ -879,15 +877,15 @@ def _validate_in_mappings(
                 target_input_def.dagster_type
             )
 
-    for input_handle in dependency_structure.input_handles():
-        if dependency_structure.has_fan_in_deps(input_handle):
-            for idx, dep in enumerate(dependency_structure.get_fan_in_deps(input_handle)):
+    for node_input in dependency_structure.inputs():
+        if dependency_structure.has_fan_in_deps(node_input):
+            for idx, dep in enumerate(dependency_structure.get_fan_in_deps(node_input)):
                 if dep is MappedInputPlaceholder:
-                    mapping_str = f"{input_handle.node_name}.{input_handle.input_name}.{idx}"
+                    mapping_str = f"{node_input.node_name}.{node_input.input_name}.{idx}"
                     if mapping_str not in mapping_keys:
                         raise DagsterInvalidDefinitionError(
                             f"Unsatisfied MappedInputPlaceholder at index {idx} in "
-                            f"MultiDependencyDefinition for '{input_handle.node_name}.{input_handle.input_name}'"
+                            f"MultiDependencyDefinition for '{node_input.node_name}.{node_input.input_name}'"
                         )
 
     # if the dagster type on a graph input is Any and all its target inputs have the
