@@ -118,7 +118,7 @@ class InputDefinition:
         asset_key: Optional[Union[AssetKey, Callable[["InputContext"], AssetKey]]] = None,
         asset_partitions: Optional[Union[Set[str], Callable[["InputContext"], Set[str]]]] = None,
         input_manager_key: Optional[str] = None
-        # when adding new params, make sure to update combine_with_inferred below
+        # when adding new params, make sure to update combine_with_inferred and with_dagster_type below
     ):
         self._name = check_valid_name(name)
 
@@ -145,7 +145,7 @@ class InputDefinition:
 
         self._input_manager_key = check.opt_str_param(input_manager_key, "input_manager_key")
 
-        self._metadata = check.opt_dict_param(metadata, "metadata", key_type=str)
+        self._metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
         self._metadata_entries = normalize_metadata(self._metadata, [], allow_invalid=True)
 
         if asset_key:
@@ -270,12 +270,14 @@ class InputDefinition:
         check.str_param(input_name, "input_name")
         check.opt_int_param(fan_in_index, "fan_in_index")
 
-        maps_to: Union[FanInInputPointer, InputPointer]
-        if fan_in_index is not None:
-            maps_to = FanInInputPointer(solid_name, input_name, fan_in_index)
-        else:
-            maps_to = InputPointer(solid_name, input_name)
-        return InputMapping(self, maps_to)
+        return InputMapping(
+            graph_input_name=self.name,
+            mapped_node_name=solid_name,
+            mapped_node_input_name=input_name,
+            fan_in_index=fan_in_index,
+            graph_input_description=self.description,
+            dagster_type=self.dagster_type,
+        )
 
     @staticmethod
     def create_from_inferred(inferred: InferredInputProps) -> "InputDefinition":
@@ -321,6 +323,19 @@ class InputDefinition:
             input_manager_key=self._input_manager_key,
         )
 
+    def with_dagster_type(self, dagster_type: DagsterType) -> "InputDefinition":
+        return InputDefinition(
+            name=self.name,
+            dagster_type=dagster_type,
+            description=self.description,
+            default_value=self.default_value if self.has_default_value else NoValueSentinel,
+            root_manager_key=self._root_manager_key,
+            metadata=self._metadata,
+            asset_key=self._asset_key,
+            asset_partitions=self._asset_partitions_fn,
+            input_manager_key=self._input_manager_key,
+        )
+
 
 def _checked_inferred_type(inferred: InferredInputProps) -> DagsterType:
     try:
@@ -351,6 +366,10 @@ class InputPointer(NamedTuple("_InputPointer", [("solid_name", str), ("input_nam
             check.str_param(input_name, "input_name"),
         )
 
+    @property
+    def node_name(self) -> str:
+        return self.solid_name
+
 
 class FanInInputPointer(
     NamedTuple(
@@ -365,21 +384,64 @@ class FanInInputPointer(
             check.int_param(fan_in_index, "fan_in_index"),
         )
 
+    @property
+    def node_name(self) -> str:
+        return self.solid_name
 
-class InputMapping(
-    NamedTuple(
-        "_InputMapping",
-        [("definition", InputDefinition), ("maps_to", Union[InputPointer, FanInInputPointer])],
-    )
-):
-    """Defines an input mapping for a graph."""
 
-    def __new__(cls, definition: InputDefinition, maps_to: Union[InputPointer, FanInInputPointer]):
-        return super(InputMapping, cls).__new__(
-            cls,
-            check.inst_param(definition, "definition", InputDefinition),
-            check.inst_param(maps_to, "maps_to", (InputPointer, FanInInputPointer)),
-        )
+class InputMapping(NamedTuple):
+    """Defines an input mapping for a graph.
+
+    Args:
+        graph_input_name (str): Name of the input in the graph being mapped from.
+        mapped_node_name (str): Named of the node (op/graph) that the input is being mapped to.
+        mapped_node_input_name (str): Name of the input in the node (op/graph) that is being mapped to.
+        fan_in_index (Optional[int]): The index in to a fanned input, otherwise None.
+        graph_input_description (Optional[str]): A description of the input in the graph being mapped from.
+        dagster_type (Optional[DagsterType]): (Deprecated) The dagster type of the graph's input
+            being mapped from. Users should not use this argument when instantiating the class.
+
+    Examples:
+
+        .. code-block:: python
+
+            from dagster import InputMapping, GraphDefinition, op, graph
+
+            @op
+            def needs_input(x):
+                return x + 1
+
+            # The following two graph definitions are equivalent
+            GraphDefinition(
+                name="the_graph",
+                node_defs=[needs_input],
+                input_mappings=[
+                    InputMapping(
+                        graph_input_name="maps_x", mapped_node_name="needs_input",
+                        mapped_node_input_name="x"
+                    )
+                ]
+            )
+
+            @graph
+            def the_graph(maps_x):
+                needs_input(maps_x)
+    """
+
+    graph_input_name: str
+    mapped_node_name: str
+    mapped_node_input_name: str
+    fan_in_index: Optional[int] = None
+    graph_input_description: Optional[str] = None
+    dagster_type: Optional[DagsterType] = None
+
+    @property
+    def maps_to(self) -> Union[InputPointer, FanInInputPointer]:
+        if self.fan_in_index is not None:
+            return FanInInputPointer(
+                self.mapped_node_name, self.mapped_node_input_name, self.fan_in_index
+            )
+        return InputPointer(self.mapped_node_name, self.mapped_node_input_name)
 
     @property
     def maps_to_fan_in(self) -> bool:
@@ -387,7 +449,16 @@ class InputMapping(
 
     def describe(self) -> str:
         idx = self.maps_to.fan_in_index if isinstance(self.maps_to, FanInInputPointer) else ""
-        return f"{self.definition.name} -> {self.maps_to.solid_name}:{self.maps_to.input_name}{idx}"
+        return (
+            f"{self.graph_input_name} -> {self.maps_to.solid_name}:{self.maps_to.input_name}{idx}"
+        )
+
+    def get_definition(self) -> "InputDefinition":
+        return InputDefinition(
+            name=self.graph_input_name,
+            description=self.graph_input_description,
+            dagster_type=self.dagster_type,
+        )
 
 
 class In(
@@ -466,7 +537,7 @@ class In(
             description=check.opt_str_param(description, "description"),
             default_value=default_value,
             root_manager_key=check.opt_str_param(root_manager_key, "root_manager_key"),
-            metadata=check.opt_dict_param(metadata, "metadata", key_type=str),
+            metadata=check.opt_mapping_param(metadata, "metadata", key_type=str),
             asset_key=check.opt_inst_param(asset_key, "asset_key", (AssetKey, FunctionType)),  # type: ignore  # (mypy bug)
             asset_partitions=asset_partitions,
             input_manager_key=check.opt_str_param(input_manager_key, "input_manager_key"),
