@@ -41,7 +41,7 @@ from ..errors import (
     ScheduleExecutionError,
     user_code_error_boundary,
 )
-from ..storage.pipeline_run import PipelineRun
+from ..storage.pipeline_run import DagsterRun
 from .config import ConfigMapping
 from .mode import DEFAULT_MODE_NAME
 from .run_request import RunRequest, SkipReason
@@ -592,7 +592,7 @@ class PartitionSetDefinition(Generic[T]):
         user_tags = validate_tags(
             self._user_defined_tags_fn_for_partition(partition), allow_reserved_tags=False  # type: ignore
         )
-        tags = merge_dicts(user_tags, PipelineRun.tags_for_partition_set(self, partition))
+        tags = merge_dicts(user_tags, DagsterRun.tags_for_partition_set(self, partition))
 
         return tags
 
@@ -1045,10 +1045,12 @@ class DefaultPartitionsSubset(PartitionsSubset):
         return DefaultPartitionsSubset(self._partitions_def, self._subset | set(partition_keys))
 
     def serialize(self) -> str:
-        return json.dumps(self._subset)
+        return json.dumps(list(self._subset))
 
     @staticmethod
     def from_serialized(
         partitions_def: PartitionsDefinition, serialized: str
     ) -> "DefaultPartitionsSubset":
-        return DefaultPartitionsSubset(subset=json.loads(serialized), partitions_def=partitions_def)
+        return DefaultPartitionsSubset(
+            subset=set(json.loads(serialized)), partitions_def=partitions_def
+        )
