@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import inspect
 import os
 import sys
@@ -6,15 +8,20 @@ from typing import (
     TYPE_CHECKING,
     AbstractSet,
     Any,
-    FrozenSet,
+    Callable,
+    List,
     Mapping,
     NamedTuple,
     Optional,
     Sequence,
+    Tuple,
+    TypeVar,
     Union,
     overload,
 )
 
+from typing_extensions import TypeAlias
+
 import dagster._check as check
 import dagster._seven as seven
 from dagster._annotations import experimental
@@ -39,7 +46,11 @@ from .events import AssetKey
 from .pipeline_base import IPipeline
 
 if TYPE_CHECKING:
-    from dagster._core.definitions.repository_definition import RepositoryLoadData
+    from dagster._core.definitions.job_definition import JobDefinition
+    from dagster._core.definitions.repository_definition import (
+        PendingRepositoryDefinition,
+        RepositoryLoadData,
+    )
 
     from .asset_group import AssetGroup
     from .graph_definition import GraphDefinition
@@ -68,12 +79,12 @@ class ReconstructableRepository(
 ):
     def __new__(
         cls,
-        pointer,
-        container_image=None,
-        executable_path=None,
-        entry_point=None,
-        container_context=None,
-        repository_load_data=None,
+        pointer: CodePointer,
+        container_image: Optional[str] = None,
+        executable_path: Optional[str] = None,
+        entry_point: Optional[Sequence[str]] = None,
+        container_context: Optional[Mapping[str, Any]] = None,
+        repository_load_data: Optional[RepositoryLoadData] = None,
     ):
         from dagster._core.definitions.repository_definition import RepositoryLoadData
 
@@ -83,13 +94,13 @@ class ReconstructableRepository(
             container_image=check.opt_str_param(container_image, "container_image"),
             executable_path=check.opt_str_param(executable_path, "executable_path"),
             entry_point=(
-                frozenlist(check.list_param(entry_point, "entry_point", of_type=str))
-                if entry_point != None
+                frozenlist(check.sequence_param(entry_point, "entry_point", of_type=str))
+                if entry_point is not None
                 else DEFAULT_DAGSTER_ENTRY_POINT
             ),
             container_context=(
-                make_readonly_value(check.opt_dict_param(container_context, "container_context"))
-                if container_context != None
+                make_readonly_value(check.mapping_param(container_context, "container_context"))
+                if container_context is not None
                 else None
             ),
             repository_load_data=check.opt_inst_param(
@@ -102,16 +113,21 @@ class ReconstructableRepository(
     ) -> "ReconstructableRepository":
         return self._replace(repository_load_data=metadata)
 
-    def get_definition(self):
+    def get_definition(self) -> "RepositoryDefinition":
         return repository_def_from_pointer(self.pointer, self.repository_load_data)
 
-    def get_reconstructable_pipeline(self, name):
+    def get_reconstructable_pipeline(self, name: str) -> ReconstructablePipeline:
         return ReconstructablePipeline(self, name)
 
     @classmethod
     def for_file(
-        cls, file, fn_name, working_directory=None, container_image=None, container_context=None
-    ):
+        cls,
+        file: str,
+        fn_name: str,
+        working_directory: Optional[str] = None,
+        container_image: Optional[str] = None,
+        container_context: Optional[Mapping[str, Any]] = None,
+    ) -> ReconstructableRepository:
         if not working_directory:
             working_directory = os.getcwd()
         return cls(
@@ -122,15 +138,20 @@ class ReconstructableRepository(
 
     @classmethod
     def for_module(
-        cls, module, fn_name, working_directory=None, container_image=None, container_context=None
-    ):
+        cls,
+        module: str,
+        fn_name: str,
+        working_directory: Optional[str] = None,
+        container_image: Optional[str] = None,
+        container_context: Optional[Mapping[str, Any]] = None,
+    ) -> ReconstructableRepository:
         return cls(
             ModuleCodePointer(module, fn_name, working_directory),
             container_image=container_image,
             container_context=container_context,
         )
 
-    def get_python_origin(self):
+    def get_python_origin(self) -> RepositoryPythonOrigin:
         return RepositoryPythonOrigin(
             executable_path=self.executable_path if self.executable_path else sys.executable,
             code_pointer=self.pointer,
@@ -139,7 +160,7 @@ class ReconstructableRepository(
             container_context=self.container_context,
         )
 
-    def get_python_origin_id(self):
+    def get_python_origin_id(self) -> str:
         return self.get_python_origin().get_id()
 
 
@@ -151,8 +172,8 @@ class ReconstructablePipeline(
             ("repository", ReconstructableRepository),
             ("pipeline_name", str),
             ("solid_selection_str", Optional[str]),
-            ("solids_to_execute", Optional[FrozenSet[str]]),
-            ("asset_selection", Optional[FrozenSet[AssetKey]]),
+            ("solids_to_execute", Optional[AbstractSet[str]]),
+            ("asset_selection", Optional[AbstractSet[AssetKey]]),
         ],
     ),
     IPipeline,
@@ -175,11 +196,11 @@ class ReconstructablePipeline(
 
     def __new__(
         cls,
-        repository,
-        pipeline_name,
-        solid_selection_str=None,
-        solids_to_execute=None,
-        asset_selection=None,
+        repository: ReconstructableRepository,
+        pipeline_name: str,
+        solid_selection_str: Optional[str] = None,
+        solids_to_execute: Optional[AbstractSet[str]] = None,
+        asset_selection: Optional[AbstractSet[AssetKey]] = None,
     ):
         check.opt_set_param(solids_to_execute, "solids_to_execute", of_type=str)
         check.opt_set_param(asset_selection, "asset_selection", AssetKey)
@@ -194,7 +215,7 @@ class ReconstructablePipeline(
 
     def with_repository_load_data(
         self, metadata: Optional["RepositoryLoadData"]
-    ) -> "ReconstructablePipeline":
+    ) -> ReconstructablePipeline:
         return self._replace(repository=self.repository.with_repository_load_data(metadata))
 
     @property
@@ -203,8 +224,8 @@ class ReconstructablePipeline(
 
     # Keep the most recent 1 definition (globally since this is a NamedTuple method)
     # This allows repeated calls to get_definition in execution paths to not reload the job
-    @lru_cache(maxsize=1)
-    def get_definition(self):
+    @lru_cache(maxsize=1)  # type: ignore
+    def get_definition(self) -> Union[JobDefinition, "PipelineDefinition"]:
         return self.repository.get_definition().get_maybe_subset_job_def(
             self.pipeline_name,
             self.solid_selection,
@@ -212,7 +233,7 @@ class ReconstructablePipeline(
             self.solids_to_execute,
         )
 
-    def get_reconstructable_repository(self):
+    def get_reconstructable_repository(self) -> ReconstructableRepository:
         return self.repository
 
     def _subset_for_execution(
@@ -247,7 +268,7 @@ class ReconstructablePipeline(
                 solids_to_execute=None,
                 asset_selection=asset_selection,
             )
-        elif isinstance(pipeline_def, PipelineDefinition):
+        elif isinstance(pipeline_def, PipelineDefinition):  # type: ignore
             # when subselecting a pipeline
             # * pipeline subselection depend on solids_to_excute rather than solid_selection
             # * we resolve a list of solid selection queries to a frozenset of qualified solid names
@@ -267,7 +288,7 @@ class ReconstructablePipeline(
     def subset_for_execution(
         self,
         solid_selection: Optional[Sequence[str]] = None,
-        asset_selection: Optional[FrozenSet[AssetKey]] = None,
+        asset_selection: Optional[AbstractSet[AssetKey]] = None,
     ) -> "ReconstructablePipeline":
         # take a list of unresolved selection queries
         check.opt_sequence_param(solid_selection, "solid_selection", of_type=str)
@@ -286,7 +307,7 @@ class ReconstructablePipeline(
         self,
         solids_to_execute: Optional[AbstractSet[str]] = None,
         asset_selection: Optional[AbstractSet[AssetKey]] = None,
-    ) -> "ReconstructablePipeline":
+    ) -> ReconstructablePipeline:
         # take a frozenset of resolved solid names from an existing pipeline
         # so there's no need to parse the selection
 
@@ -304,27 +325,27 @@ class ReconstructablePipeline(
             asset_selection=asset_selection,
         )
 
-    def describe(self):
+    def describe(self) -> str:
         return '"{name}" in repository ({repo})'.format(
             repo=self.repository.pointer.describe, name=self.pipeline_name
         )
 
     @staticmethod
-    def for_file(python_file, fn_name):
+    def for_file(python_file: str, fn_name: str) -> ReconstructablePipeline:
         return bootstrap_standalone_recon_pipeline(
             FileCodePointer(python_file, fn_name, os.getcwd())
         )
 
     @staticmethod
-    def for_module(module, fn_name):
+    def for_module(module: str, fn_name: str) -> ReconstructablePipeline:
         return bootstrap_standalone_recon_pipeline(ModuleCodePointer(module, fn_name, os.getcwd()))
 
-    def to_dict(self):
+    def to_dict(self) -> Mapping[str, object]:
         return pack_value(self)
 
     @staticmethod
-    def from_dict(val):
-        check.dict_param(val, "val")
+    def from_dict(val: Mapping[str, object]) -> ReconstructablePipeline:
+        check.mapping_param(val, "val")
 
         inst = unpack_value(val)
         check.invariant(
@@ -335,10 +356,10 @@ class ReconstructablePipeline(
         )
         return inst
 
-    def get_python_origin(self):
+    def get_python_origin(self) -> PipelinePythonOrigin:
         return PipelinePythonOrigin(self.pipeline_name, self.repository.get_python_origin())
 
-    def get_python_origin_id(self):
+    def get_python_origin_id(self) -> str:
         return self.get_python_origin().get_id()
 
     def get_module(self) -> Optional[str]:
@@ -353,7 +374,7 @@ class ReconstructablePipeline(
 ReconstructableJob = ReconstructablePipeline
 
 
-def reconstructable(target):
+def reconstructable(target: Callable[..., "PipelineDefinition"]) -> ReconstructablePipeline:
     """
     Create a :py:class:`~dagster._core.definitions.reconstructable.ReconstructablePipeline` from a
     function that returns a :py:class:`~dagster.PipelineDefinition`/:py:class:`~dagster.JobDefinition`,
@@ -449,7 +470,7 @@ def reconstructable(target):
         if (
             hasattr(target, "__module__")
             and hasattr(target, "__name__")
-            and inspect.getmodule(target).__name__ != "__main__"
+            and getattr(inspect.getmodule(target), "__name__", None) != "__main__"
         ):
             return ReconstructablePipeline.for_module(target.__module__, target.__name__)
     except:
@@ -472,12 +493,12 @@ def reconstructable(target):
 
 @experimental
 def build_reconstructable_job(
-    reconstructor_module_name,
-    reconstructor_function_name,
-    reconstructable_args=None,
-    reconstructable_kwargs=None,
-    reconstructor_working_directory=None,
-):
+    reconstructor_module_name: str,
+    reconstructor_function_name: str,
+    reconstructable_args: Optional[Tuple[object]] = None,
+    reconstructable_kwargs: Optional[Mapping[str, object]] = None,
+    reconstructor_working_directory: Optional[str] = None,
+) -> ReconstructablePipeline:
     """
     Create a :py:class:`dagster._core.definitions.reconstructable.ReconstructablePipeline`.
 
@@ -546,11 +567,13 @@ def build_reconstructable_job(
         reconstructor_working_directory, "reconstructor_working_directory", os.getcwd()
     )
 
-    reconstructable_args = list(check.opt_tuple_param(reconstructable_args, "reconstructable_args"))
-    reconstructable_kwargs = list(
+    _reconstructable_args: List[object] = list(
+        check.opt_tuple_param(reconstructable_args, "reconstructable_args")
+    )
+    _reconstructable_kwargs: List[List[Union[str, object]]] = list(
         (
             [key, value]
-            for key, value in check.opt_dict_param(
+            for key, value in check.opt_mapping_param(
                 reconstructable_kwargs, "reconstructable_kwargs", key_type=str
             ).items()
         )
@@ -562,7 +585,7 @@ def build_reconstructable_job(
         working_directory=reconstructor_working_directory,
     )
 
-    pointer = CustomPointer(reconstructor_pointer, reconstructable_args, reconstructable_kwargs)
+    pointer = CustomPointer(reconstructor_pointer, _reconstructable_args, _reconstructable_kwargs)
 
     pipeline_def = pipeline_def_from_pointer(pointer)
 
@@ -577,7 +600,7 @@ build_reconstructable_pipeline = build_reconstructable_job
 build_reconstructable_target = build_reconstructable_job
 
 
-def bootstrap_standalone_recon_pipeline(pointer):
+def bootstrap_standalone_recon_pipeline(pointer: CodePointer) -> ReconstructablePipeline:
     # So this actually straps the the pipeline for the sole
     # purpose of getting the pipeline name. If we changed ReconstructablePipeline
     # to get the pipeline on demand in order to get name, we could avoid this.
@@ -588,9 +611,21 @@ def bootstrap_standalone_recon_pipeline(pointer):
     )
 
 
-def _check_is_loadable(definition):
+LoadableDefinition: TypeAlias = Union[
+    "PipelineDefinition",
+    "RepositoryDefinition",
+    "PendingRepositoryDefinition",
+    "GraphDefinition",
+    "AssetGroup",
+]
+
+T_LoadableDefinition = TypeVar("T_LoadableDefinition", bound=LoadableDefinition)
+
+
+def _check_is_loadable(definition: T_LoadableDefinition) -> T_LoadableDefinition:
     from dagster._core.definitions import AssetGroup
 
+    from .definitions_class import Definitions
     from .graph_definition import GraphDefinition
     from .pipeline_definition import PipelineDefinition
     from .repository_definition import PendingRepositoryDefinition, RepositoryDefinition
@@ -603,6 +638,7 @@ def _check_is_loadable(definition):
             PendingRepositoryDefinition,
             GraphDefinition,
             AssetGroup,
+            Definitions,
         ),
     ):
         raise DagsterInvariantViolationError(
@@ -611,26 +647,32 @@ def _check_is_loadable(definition):
                 f"PipelineDefinition, AssetGroup, or RepositoryDefinition. Got {repr(definition)}."
             )
         )
-    return definition
+    return definition  # type: ignore
 
 
-def load_def_in_module(module_name, attribute, working_directory):
+def load_def_in_module(
+    module_name: str, attribute: str, working_directory: Optional[str]
+) -> LoadableDefinition:
     return def_from_pointer(CodePointer.from_module(module_name, attribute, working_directory))
 
 
-def load_def_in_package(package_name, attribute, working_directory):
+def load_def_in_package(
+    package_name: str, attribute: str, working_directory: Optional[str]
+) -> LoadableDefinition:
     return def_from_pointer(
         CodePointer.from_python_package(package_name, attribute, working_directory)
     )
 
 
-def load_def_in_python_file(python_file, attribute, working_directory):
+def load_def_in_python_file(
+    python_file: str, attribute: str, working_directory: Optional[str]
+) -> LoadableDefinition:
     return def_from_pointer(CodePointer.from_python_file(python_file, attribute, working_directory))
 
 
 def def_from_pointer(
     pointer: CodePointer,
-) -> Union["PipelineDefinition", "RepositoryDefinition", "GraphDefinition"]:
+) -> LoadableDefinition:
     target = pointer.load_target()
 
     from dagster._core.definitions import AssetGroup
@@ -649,7 +691,7 @@ def def_from_pointer(
             AssetGroup,
         ),
     ) or not callable(target):
-        return _check_is_loadable(target)
+        return _check_is_loadable(target)  # type: ignore
 
     # if its a function invoke it - otherwise we are pointing to a
     # artifact in module scope, likely decorator output
@@ -662,7 +704,7 @@ def def_from_pointer(
             )
         )
 
-    return _check_is_loadable(target())
+    return _check_is_loadable(target())  # type: ignore
 
 
 def pipeline_def_from_pointer(pointer: CodePointer) -> "PipelineDefinition":
@@ -700,14 +742,20 @@ def repository_def_from_target_def(
 ) -> Optional["RepositoryDefinition"]:
     from dagster._core.definitions import AssetGroup
 
+    from .definitions_class import Definitions
     from .graph_definition import GraphDefinition
     from .pipeline_definition import PipelineDefinition
     from .repository_definition import (
+        SINGLETON_REPOSITORY_NAME,
         CachingRepositoryData,
         PendingRepositoryDefinition,
         RepositoryDefinition,
     )
 
+    if isinstance(target, Definitions):
+        # reassign to handle both repository and pending repo case
+        target = target.get_inner_repository()
+
     # special case - we can wrap a single pipeline in a repository
     if isinstance(target, (PipelineDefinition, GraphDefinition)):
         # consider including pipeline name in generated repo name
@@ -717,7 +765,8 @@ def repository_def_from_target_def(
         )
     elif isinstance(target, AssetGroup):
         return RepositoryDefinition(
-            name="__repository__", repository_data=CachingRepositoryData.from_list([target])
+            name=SINGLETON_REPOSITORY_NAME,
+            repository_data=CachingRepositoryData.from_list([target]),
         )
     elif isinstance(target, RepositoryDefinition):
         return target
