@@ -1,9 +1,10 @@
 import sys
 from contextlib import contextmanager
 from typing import (
+    AbstractSet,
     Any,
+    Callable,
     Dict,
-    FrozenSet,
     Iterator,
     Mapping,
     NamedTuple,
@@ -32,12 +33,7 @@ from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.execution.retries import RetryMode
 from dagster._core.instance import DagsterInstance, InstanceRef
 from dagster._core.selector import parse_step_selection
-from dagster._core.storage.pipeline_run import (
-    DagsterRun,
-    DagsterRunStatus,
-    PipelineRun,
-    PipelineRunStatus,
-)
+from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
 from dagster._core.system_config.objects import ResolvedRunConfig
 from dagster._core.telemetry import log_repo_stats, telemetry_wrapper
 from dagster._core.utils import str_format_set
@@ -56,20 +52,20 @@ from .execute_job_result import ExecuteJobResult
 from .results import PipelineExecutionResult
 
 ## Brief guide to the execution APIs
-# | function name               | operates over      | sync  | supports    | creates new PipelineRun |
+# | function name               | operates over      | sync  | supports    | creates new DagsterRun  |
 # |                             |                    |       | reexecution | in instance             |
 # | --------------------------- | ------------------ | ----- | ----------- | ----------------------- |
 # | execute_pipeline_iterator   | IPipeline          | async | no          | yes                     |
 # | execute_pipeline            | IPipeline          | sync  | no          | yes                     |
-# | execute_run_iterator        | PipelineRun        | async | (1)         | no                      |
-# | execute_run                 | PipelineRun        | sync  | (1)         | no                      |
+# | execute_run_iterator        | DagsterRun         | async | (1)         | no                      |
+# | execute_run                 | DagsterRun         | sync  | (1)         | no                      |
 # | execute_plan_iterator       | ExecutionPlan      | async | (2)         | no                      |
 # | execute_plan                | ExecutionPlan      | sync  | (2)         | no                      |
 # | reexecute_pipeline          | IPipeline          | sync  | yes         | yes                     |
 # | reexecute_pipeline_iterator | IPipeline          | async | yes         | yes                     |
 #
 # Notes on reexecution support:
-# (1) The appropriate bits must be set on the PipelineRun passed to this function. Specifically,
+# (1) The appropriate bits must be set on the DagsterRun passed to this function. Specifically,
 #     parent_run_id and root_run_id must be set and consistent, and if a solids_to_execute or
 #     step_keys_to_execute are set they must be consistent with the parent and root runs.
 # (2) As for (1), but the ExecutionPlan passed must also agree in all relevant bits.
@@ -77,15 +73,15 @@ from .results import PipelineExecutionResult
 
 def execute_run_iterator(
     pipeline: IPipeline,
-    pipeline_run: PipelineRun,
+    pipeline_run: DagsterRun,
     instance: DagsterInstance,
     resume_from_failure: bool = False,
 ) -> Iterator[DagsterEvent]:
     check.inst_param(pipeline, "pipeline", IPipeline)
-    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
     check.inst_param(instance, "instance", DagsterInstance)
 
-    if pipeline_run.status == PipelineRunStatus.CANCELED:
+    if pipeline_run.status == DagsterRunStatus.CANCELED:
         # This can happen if the run was force-terminated while it was starting
         def gen_execute_on_cancel():
             yield instance.report_engine_event(
@@ -96,7 +92,7 @@ def execute_run_iterator(
         return gen_execute_on_cancel()
 
     if not resume_from_failure:
-        if pipeline_run.status not in (PipelineRunStatus.NOT_STARTED, PipelineRunStatus.STARTING):
+        if pipeline_run.status not in (DagsterRunStatus.NOT_STARTED, DagsterRunStatus.STARTING):
             if instance.run_monitoring_enabled:
                 # This can happen if the pod was unexpectedly restarted by the cluster - ignore it since
                 # the run monitoring daemon will also spin up a new pod
@@ -132,8 +128,8 @@ def execute_run_iterator(
 
     else:
         check.invariant(
-            pipeline_run.status == PipelineRunStatus.STARTED
-            or pipeline_run.status == PipelineRunStatus.STARTING,
+            pipeline_run.status == DagsterRunStatus.STARTED
+            or pipeline_run.status == DagsterRunStatus.STARTING,
             desc="Run of {} ({}) in state {}, expected STARTED or STARTING because it's "
             "resuming from a run worker failure".format(
                 pipeline_run.pipeline_name, pipeline_run.run_id, pipeline_run.status
@@ -145,7 +141,7 @@ def execute_run_iterator(
         if isinstance(pipeline_def, PipelineSubsetDefinition):
             check.invariant(
                 pipeline_run.solids_to_execute == pipeline.solids_to_execute,
-                "Cannot execute PipelineRun with solids_to_execute {solids_to_execute} that conflicts "
+                "Cannot execute DagsterRun with solids_to_execute {solids_to_execute} that conflicts "
                 "with pipeline subset {pipeline_solids_to_execute}.".format(
                     pipeline_solids_to_execute=str_format_set(pipeline.solids_to_execute),
                     solids_to_execute=str_format_set(pipeline_run.solids_to_execute),
@@ -153,7 +149,7 @@ def execute_run_iterator(
             )
         else:
             # when `execute_run_iterator` is directly called, the sub pipeline hasn't been created
-            # note that when we receive the solids to execute via PipelineRun, it won't support
+            # note that when we receive the solids to execute via DagsterRun, it won't support
             # solid selection query syntax
             pipeline = pipeline.subset_for_execution_from_existing_pipeline(
                 frozenset(pipeline_run.solids_to_execute)
@@ -188,7 +184,7 @@ def execute_run_iterator(
 
 def execute_run(
     pipeline: IPipeline,
-    pipeline_run: PipelineRun,
+    pipeline_run: DagsterRun,
     instance: DagsterInstance,
     raise_on_error: bool = False,
 ) -> PipelineExecutionResult:
@@ -198,7 +194,7 @@ def execute_run(
 
     Args:
         pipeline (IPipeline): The pipeline to execute.
-        pipeline_run (PipelineRun): The run to execute
+        pipeline_run (DagsterRun): The run to execute
         instance (DagsterInstance): The instance in which the run has been created.
         raise_on_error (Optional[bool]): Whether or not to raise exceptions when they occur.
             Defaults to ``False``.
@@ -220,10 +216,10 @@ def execute_run(
         )
 
     check.inst_param(pipeline, "pipeline", IPipeline)
-    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
     check.inst_param(instance, "instance", DagsterInstance)
 
-    if pipeline_run.status == PipelineRunStatus.CANCELED:
+    if pipeline_run.status == DagsterRunStatus.CANCELED:
         message = "Not starting execution since the run was canceled before execution could start"
         instance.report_engine_event(
             message,
@@ -232,8 +228,8 @@ def execute_run(
         raise DagsterInvariantViolationError(message)
 
     check.invariant(
-        pipeline_run.status == PipelineRunStatus.NOT_STARTED
-        or pipeline_run.status == PipelineRunStatus.STARTING,
+        pipeline_run.status == DagsterRunStatus.NOT_STARTED
+        or pipeline_run.status == DagsterRunStatus.STARTING,
         desc="Run {} ({}) in state {}, expected NOT_STARTED or STARTING".format(
             pipeline_run.pipeline_name, pipeline_run.run_id, pipeline_run.status
         ),
@@ -243,7 +239,7 @@ def execute_run(
         if isinstance(pipeline_def, PipelineSubsetDefinition):
             check.invariant(
                 pipeline_run.solids_to_execute == pipeline.solids_to_execute,
-                "Cannot execute PipelineRun with solids_to_execute {solids_to_execute} that "
+                "Cannot execute DagsterRun with solids_to_execute {solids_to_execute} that "
                 "conflicts with pipeline subset {pipeline_solids_to_execute}.".format(
                     pipeline_solids_to_execute=str_format_set(pipeline.solids_to_execute),
                     solids_to_execute=str_format_set(pipeline_run.solids_to_execute),
@@ -251,7 +247,7 @@ def execute_run(
             )
         else:
             # when `execute_run` is directly called, the sub pipeline hasn't been created
-            # note that when we receive the solids to execute via PipelineRun, it won't support
+            # note that when we receive the solids to execute via DagsterRun, it won't support
             # solid selection query syntax
             pipeline = pipeline.subset_for_execution_from_existing_pipeline(
                 frozenset(pipeline_run.solids_to_execute)
@@ -303,7 +299,7 @@ def execute_pipeline_iterator(
     run_config: Optional[Mapping[str, object]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
-    tags: Optional[Mapping[str, Any]] = None,
+    tags: Optional[Mapping[str, str]] = None,
     solid_selection: Optional[Sequence[str]] = None,
     instance: Optional[DagsterInstance] = None,
 ) -> Iterator[DagsterEvent]:
@@ -538,7 +534,7 @@ def execute_job(
     check.opt_sequence_param(asset_selection, "asset_selection", of_type=AssetKey)
 
     # get the repository load data here because we call job.get_definition() later in this fn
-    job, _ = _pipeline_with_repository_load_data(job)
+    job_def, _ = _pipeline_with_repository_load_data(job)
 
     if reexecution_options is not None and op_selection is not None:
         raise DagsterInvariantViolationError(
@@ -550,7 +546,7 @@ def execute_job(
             run = check.not_none(instance.get_run_by_id(reexecution_options.parent_run_id))
             run_config = run.run_config
         result = reexecute_pipeline(
-            pipeline=job,
+            pipeline=job_def,
             parent_run_id=reexecution_options.parent_run_id,
             run_config=run_config,
             step_selection=list(reexecution_options.step_selection),
@@ -562,7 +558,7 @@ def execute_job(
         )
     else:
         result = _logged_execute_pipeline(
-            pipeline=job,
+            pipeline=job_def,
             instance=instance,
             run_config=run_config,
             mode=None,
@@ -575,7 +571,7 @@ def execute_job(
 
     # We use PipelineExecutionResult to construct the JobExecutionResult.
     return ExecuteJobResult(
-        job_def=cast(ReconstructableJob, job).get_definition(),
+        job_def=cast(ReconstructableJob, job_def).get_definition(),
         reconstruct_context=result.reconstruct_context(),
         event_list=result.event_list,
         dagster_run=instance.get_run_by_id(result.run_id),
@@ -584,10 +580,10 @@ def execute_job(
 
 def execute_pipeline(
     pipeline: Union[PipelineDefinition, IPipeline],
-    run_config: Optional[Mapping] = None,
+    run_config: Optional[Mapping[str, object]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
-    tags: Optional[Mapping[str, Any]] = None,
+    tags: Optional[Mapping[str, str]] = None,
     solid_selection: Optional[Sequence[str]] = None,
     instance: Optional[DagsterInstance] = None,
     raise_on_error: bool = True,
@@ -644,10 +640,10 @@ def execute_pipeline(
 def _logged_execute_pipeline(
     pipeline: Union[IPipeline, PipelineDefinition],
     instance: DagsterInstance,
-    run_config: Optional[dict] = None,
+    run_config: Optional[Mapping[str, object]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
-    tags: Optional[Mapping[str, Any]] = None,
+    tags: Optional[Mapping[str, str]] = None,
     solid_selection: Optional[Sequence[str]] = None,
     raise_on_error: bool = True,
     asset_selection: Optional[Sequence[AssetKey]] = None,
@@ -699,11 +695,11 @@ def _logged_execute_pipeline(
 def reexecute_pipeline(
     pipeline: Union[IPipeline, PipelineDefinition],
     parent_run_id: str,
-    run_config: Optional[Mapping] = None,
+    run_config: Optional[Mapping[str, object]] = None,
     step_selection: Optional[Sequence[str]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
-    tags: Optional[Mapping[str, Any]] = None,
+    tags: Optional[Mapping[str, str]] = None,
     instance: Optional[DagsterInstance] = None,
     raise_on_error: bool = True,
 ) -> PipelineExecutionResult:
@@ -810,6 +806,7 @@ def reexecute_pipeline(
             execute_instance,
             raise_on_error=raise_on_error,
         )
+    check.failed("Should not reach here.")
 
 
 def reexecute_pipeline_iterator(
@@ -819,7 +816,7 @@ def reexecute_pipeline_iterator(
     step_selection: Optional[Sequence[str]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
-    tags: Optional[Mapping[str, Any]] = None,
+    tags: Optional[Mapping[str, str]] = None,
     instance: Optional[DagsterInstance] = None,
 ) -> Iterator[DagsterEvent]:
     """Reexecute a pipeline iteratively.
@@ -909,19 +906,20 @@ def reexecute_pipeline_iterator(
         )
 
         return execute_run_iterator(pipeline, pipeline_run, execute_instance)
+    check.failed("Should not reach here.")
 
 
 def execute_plan_iterator(
     execution_plan: ExecutionPlan,
     pipeline: IPipeline,
-    pipeline_run: PipelineRun,
+    pipeline_run: DagsterRun,
     instance: DagsterInstance,
     retry_mode: Optional[RetryMode] = None,
     run_config: Optional[Mapping[str, object]] = None,
 ) -> Iterator[DagsterEvent]:
     check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
     check.inst_param(pipeline, "pipeline", IPipeline)
-    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
     check.inst_param(instance, "instance", DagsterInstance)
     retry_mode = check.opt_inst_param(retry_mode, "retry_mode", RetryMode, RetryMode.DISABLED)
     run_config = check.opt_mapping_param(run_config, "run_config")
@@ -949,8 +947,8 @@ def execute_plan(
     execution_plan: ExecutionPlan,
     pipeline: IPipeline,
     instance: DagsterInstance,
-    pipeline_run: PipelineRun,
-    run_config: Optional[Mapping] = None,
+    pipeline_run: DagsterRun,
+    run_config: Optional[Mapping[str, object]] = None,
     retry_mode: Optional[RetryMode] = None,
 ) -> Sequence[DagsterEvent]:
     """This is the entry point of dagster-graphql executions. For the dagster CLI entry point, see
@@ -959,7 +957,7 @@ def execute_plan(
     check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
     check.inst_param(pipeline, "pipeline", IPipeline)
     check.inst_param(instance, "instance", DagsterInstance)
-    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
     run_config = check.opt_mapping_param(run_config, "run_config")
     check.opt_inst_param(retry_mode, "retry_mode", RetryMode)
 
@@ -985,7 +983,7 @@ def _check_pipeline(pipeline: Union[PipelineDefinition, IPipeline]) -> IPipeline
 
 
 def _get_execution_plan_from_run(
-    pipeline: IPipeline, pipeline_run: PipelineRun, instance: DagsterInstance
+    pipeline: IPipeline, pipeline_run: DagsterRun, instance: DagsterInstance
 ) -> ExecutionPlan:
 
     execution_plan_snapshot = None
@@ -1113,9 +1111,9 @@ def pipeline_execution_iterator(
     finally:
         if pipeline_canceled_info:
             reloaded_run = pipeline_context.instance.get_run_by_id(pipeline_context.run_id)
-            if reloaded_run and reloaded_run.status == PipelineRunStatus.CANCELING:
+            if reloaded_run and reloaded_run.status == DagsterRunStatus.CANCELING:
                 event = DagsterEvent.pipeline_canceled(pipeline_context, pipeline_canceled_info)
-            elif reloaded_run and reloaded_run.status == PipelineRunStatus.CANCELED:
+            elif reloaded_run and reloaded_run.status == DagsterRunStatus.CANCELED:
                 # This happens if the run was force-terminated but was still able to send
                 # a cancellation request
                 event = DagsterEvent.engine_event(
@@ -1163,7 +1161,12 @@ class ExecuteRunWithPlanIterable:
     cf. `dagster._utils.EventGenerationManager`.
     """
 
-    def __init__(self, execution_plan, iterator, execution_context_manager):
+    def __init__(
+        self,
+        execution_plan: ExecutionPlan,
+        iterator: Callable[..., Iterator[DagsterEvent]],
+        execution_context_manager: ExecutionContextManager[Any],
+    ):
         self.execution_plan = check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
         self.iterator = check.callable_param(iterator, "iterator")
         self.execution_context_manager = check.inst_param(
@@ -1201,17 +1204,17 @@ class ExecuteRunWithPlanIterable:
 
 def _check_execute_pipeline_args(
     pipeline: Union[PipelineDefinition, IPipeline],
-    run_config: Optional[Mapping],
+    run_config: Optional[Mapping[str, object]],
     mode: Optional[str],
     preset: Optional[str],
-    tags: Optional[Mapping[str, Any]],
+    tags: Optional[Mapping[str, str]],
     solid_selection: Optional[Sequence[str]] = None,
 ) -> Tuple[
     IPipeline,
     Optional[Mapping],
     Optional[str],
-    Mapping[str, Any],
-    Optional[FrozenSet[str]],
+    Mapping[str, str],
+    Optional[AbstractSet[str]],
     Optional[Sequence[str]],
 ]:
     pipeline = _check_pipeline(pipeline)
@@ -1284,7 +1287,7 @@ def _check_execute_pipeline_args(
                 (
                     "Pipeline {name} has multiple modes (Available modes: {modes}) and you have "
                     "attempted to execute it without specifying a mode. Set "
-                    "mode property on the PipelineRun object."
+                    "mode property on the DagsterRun object."
                 ).format(name=pipeline_def.name, modes=pipeline_def.available_modes)
             )
         mode = pipeline_def.get_default_mode_name()
