@@ -12,7 +12,7 @@ from dagster._core.definitions.time_window_partitions import (
 from dagster._core.errors import DagsterInvariantViolationError
 
 if TYPE_CHECKING:
-    from dagster._core.definitions import PartitionsDefinition, SolidDefinition
+    from dagster._core.definitions import OpDefinition, PartitionsDefinition
     from dagster._core.definitions.op_definition import OpDefinition
     from dagster._core.definitions.resource_definition import Resources
     from dagster._core.events import DagsterEvent
@@ -70,8 +70,8 @@ class InputContext:
     def __init__(
         self,
         name: Optional[str] = None,
-        pipeline_name: Optional[str] = None,
-        solid_def: Optional["SolidDefinition"] = None,
+        job_name: Optional[str] = None,
+        solid_def: Optional["OpDefinition"] = None,
         config: Optional[Any] = None,
         metadata: Optional[Mapping[str, Any]] = None,
         upstream_output: Optional["OutputContext"] = None,
@@ -83,12 +83,14 @@ class InputContext:
         op_def: Optional["OpDefinition"] = None,
         asset_key: Optional[AssetKey] = None,
         partition_key: Optional[str] = None,
+        asset_partition_key_range: Optional[PartitionKeyRange] = None,
+        asset_partitions_def: Optional["PartitionsDefinition"] = None,
     ):
         from dagster._core.definitions.resource_definition import IContainsGenerator, Resources
         from dagster._core.execution.build_resources import build_resources
 
         self._name = name
-        self._pipeline_name = pipeline_name
+        self._job_name = job_name
         check.invariant(
             solid_def is None or op_def is None, "Can't provide both a solid_def and an op_def arg"
         )
@@ -106,12 +108,15 @@ class InputContext:
         else:
             self._partition_key = partition_key
 
+        self._asset_partition_key_range = asset_partition_key_range
+        self._asset_partitions_def = asset_partitions_def
+
         if isinstance(resources, Resources):
             self._resources_cm = None
             self._resources = resources
         else:
             self._resources_cm = build_resources(
-                check.opt_dict_param(resources, "resources", key_type=str)
+                check.opt_mapping_param(resources, "resources", key_type=str)
             )
             self._resources = self._resources_cm.__enter__()  # pylint: disable=no-member
             self._resources_contain_cm = isinstance(self._resources, IContainsGenerator)
@@ -153,17 +158,20 @@ class InputContext:
         return self._name
 
     @property
-    def pipeline_name(self) -> str:
-        if self._pipeline_name is None:
+    def job_name(self) -> str:
+        if self._job_name is None:
             raise DagsterInvariantViolationError(
-                "Attempting to access pipeline_name, "
+                "Attempting to access job_name, "
                 "but it was not provided when constructing the InputContext"
             )
-
-        return self._pipeline_name
+        return self._job_name
 
     @property
-    def solid_def(self) -> "SolidDefinition":
+    def pipeline_name(self) -> str:
+        return self.job_name
+
+    @property
+    def solid_def(self) -> "OpDefinition":
         if self._solid_def is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access solid_def, "
@@ -263,14 +271,17 @@ class InputContext:
     @property
     def asset_partitions_def(self) -> "PartitionsDefinition":
         """The PartitionsDefinition on the upstream asset corresponding to this input."""
-        asset_key = self.asset_key
-        result = self.step_context.pipeline_def.asset_layer.partitions_def_for_asset(asset_key)
-        if result is None:
-            raise DagsterInvariantViolationError(
-                f"Attempting to access partitions def for asset {asset_key}, but it is not partitioned"
-            )
+        if self._asset_partitions_def is None:
+            if self.asset_key:
+                raise DagsterInvariantViolationError(
+                    f"Attempting to access partitions def for asset {self.asset_key}, but it is not partitioned"
+                )
+            else:
+                raise DagsterInvariantViolationError(
+                    "Attempting to access partitions def for asset, but input does not correspond to an asset"
+                )
 
-        return result
+        return self._asset_partitions_def
 
     @property
     def step_context(self) -> "StepExecutionContext":
@@ -305,10 +316,7 @@ class InputContext:
     @public  # type: ignore
     @property
     def has_asset_partitions(self) -> bool:
-        if self._step_context is not None:
-            return self._step_context.has_asset_partitions_for_input(self.name)
-        else:
-            return False
+        return self._asset_partition_key_range is not None
 
     @public  # type: ignore
     @property
@@ -318,7 +326,16 @@ class InputContext:
         Raises an error if the input asset has no partitioning, or if the run covers a partition
         range for the input asset.
         """
-        return self.step_context.asset_partition_key_for_input(self.name)
+        if self._asset_partition_key_range is None:
+            check.failed("The input does not correspond to any asset partitions.")
+        start, end = self._asset_partition_key_range
+        if start == end:
+            return start
+        else:
+            check.failed(
+                f"Tried to access partition key for asset '{self.asset_key}', "
+                f"but the step input has a partition range: '{start}' to '{end}'."
+            )
 
     @public  # type: ignore
     @property
@@ -327,7 +344,12 @@ class InputContext:
 
         Raises an error if the input asset has no partitioning.
         """
-        return self.step_context.asset_partition_key_range_for_input(self.name)
+        if self._asset_partition_key_range is None:
+            check.failed(
+                "Tried to access asset_partition_key_range, but the asset is not partitioned.",
+            )
+
+        return self._asset_partition_key_range
 
     @public  # type: ignore
     @property
@@ -492,6 +514,8 @@ def build_input_context(
     step_context: Optional["StepExecutionContext"] = None,
     asset_key: Optional["AssetKey"] = None,
     partition_key: Optional[str] = None,
+    asset_partition_key_range: Optional[PartitionKeyRange] = None,
+    asset_partitions_def: Optional["PartitionsDefinition"] = None,
 ) -> "InputContext":
     """Builds input context from provided parameters.
 
@@ -517,6 +541,9 @@ def build_input_context(
         op_def (Optional[OpDefinition]): The definition of the op that's loading the input.
         step_context (Optional[StepExecutionContext]): For internal use.
         partition_key (Optional[str]): String value representing partition key to execute with.
+        asset_partition_key_range (Optional[str]): The range of asset partition keys to load.
+        asset_partitions_def: Optional[PartitionsDefinition]: The PartitionsDefinition of the asset
+            being loaded.
 
     Examples:
 
@@ -527,7 +554,7 @@ def build_input_context(
             with build_input_context(resources={"foo": context_manager_resource}) as context:
                 do_something
     """
-    from dagster._core.definitions import OpDefinition
+    from dagster._core.definitions import OpDefinition, PartitionsDefinition
     from dagster._core.execution.context.output import OutputContext
     from dagster._core.execution.context.system import StepExecutionContext
     from dagster._core.execution.context_creation_pipeline import initialize_console_manager
@@ -543,10 +570,16 @@ def build_input_context(
     step_context = check.opt_inst_param(step_context, "step_context", StepExecutionContext)
     asset_key = check.opt_inst_param(asset_key, "asset_key", AssetKey)
     partition_key = check.opt_str_param(partition_key, "partition_key")
+    asset_partition_key_range = check.opt_inst_param(
+        asset_partition_key_range, "asset_partition_key_range", PartitionKeyRange
+    )
+    asset_partitions_def = check.opt_inst_param(
+        asset_partitions_def, "asset_partitions_def", PartitionsDefinition
+    )
 
     return InputContext(
         name=name,
-        pipeline_name=None,
+        job_name=None,
         config=config,
         metadata=metadata,
         upstream_output=upstream_output,
@@ -558,4 +591,6 @@ def build_input_context(
         op_def=op_def,
         asset_key=asset_key,
         partition_key=partition_key,
+        asset_partition_key_range=asset_partition_key_range,
+        asset_partitions_def=asset_partitions_def,
     )
