@@ -2,6 +2,8 @@ import asyncio
 import inspect
 from typing import Any, AsyncGenerator, Callable, Iterator, List, Mapping, Sequence, Set, Union
 
+from typing_extensions import TypeAlias
+
 import dagster._check as check
 from dagster._core.definitions import (
     AssetMaterialization,
@@ -14,19 +16,20 @@ from dagster._core.definitions import (
     Output,
 )
 from dagster._core.definitions.asset_layer import AssetLayer
+from dagster._core.definitions.op_definition import OpComputeFunction
 from dagster._core.errors import DagsterExecutionStepExecutionError, DagsterInvariantViolationError
 from dagster._core.events import DagsterEvent
-from dagster._core.execution.context.compute import SolidExecutionContext
+from dagster._core.execution.context.compute import OpExecutionContext
 from dagster._core.execution.context.system import StepExecutionContext
 from dagster._core.system_config.objects import ResolvedRunConfig
 from dagster._utils import iterate_with_context
 
 from .outputs import StepOutput, StepOutputProperties
-from .utils import solid_execution_error_boundary
+from .utils import op_execution_error_boundary
 
-SolidOutputUnion = Union[
-    DynamicOutput,
-    Output,
+SolidOutputUnion: TypeAlias = Union[
+    DynamicOutput[Any],
+    Output[Any],
     AssetMaterialization,
     Materialization,
     ExpectationResult,
@@ -116,7 +119,7 @@ def _yield_compute_results(
 ) -> Iterator[SolidOutputUnion]:
     check.inst_param(step_context, "step_context", StepExecutionContext)
 
-    context = SolidExecutionContext(step_context)
+    context = OpExecutionContext(step_context)
     user_event_generator = compute_fn(context, inputs)
 
     if isinstance(user_event_generator, Output):
@@ -140,7 +143,7 @@ def _yield_compute_results(
     op_label = step_context.describe_op()
 
     for event in iterate_with_context(
-        lambda: solid_execution_error_boundary(
+        lambda: op_execution_error_boundary(
             DagsterExecutionStepExecutionError,
             msg_fn=lambda: f"Error occurred while executing {op_label}:",
             step_context=step_context,
@@ -159,7 +162,7 @@ def _yield_compute_results(
 
 
 def execute_core_compute(
-    step_context: StepExecutionContext, inputs: Mapping[str, Any], compute_fn
+    step_context: StepExecutionContext, inputs: Mapping[str, Any], compute_fn: OpComputeFunction
 ) -> Iterator[SolidOutputUnion]:
     """
     Execute the user-specified compute for the solid. Wrap in an error boundary and do
