@@ -26,7 +26,7 @@ from dagster._core.definitions import (
     OutputDefinition,
     TypeCheck,
 )
-from dagster._core.definitions.decorators.solid_decorator import DecoratedSolidFunction
+from dagster._core.definitions.decorators.solid_decorator import DecoratedOpFunction
 from dagster._core.definitions.events import AssetLineageInfo, DynamicOutput
 from dagster._core.definitions.logical_version import (
     CODE_VERSION_TAG_KEY,
@@ -64,7 +64,6 @@ from dagster._core.execution.plan.inputs import StepInputData
 from dagster._core.execution.plan.objects import StepSuccessData, TypeCheckData
 from dagster._core.execution.plan.outputs import StepOutputData, StepOutputHandle
 from dagster._core.execution.resolve_versions import resolve_step_output_versions
-from dagster._core.storage.io_manager import IOManager
 from dagster._core.storage.tags import MEMOIZED_RUN_TAG
 from dagster._core.types.dagster_type import DagsterType
 from dagster._utils import ensure_gen, iterate_with_context
@@ -73,7 +72,7 @@ from dagster._utils.timing import time_execution_scope
 
 from .compute import SolidOutputUnion
 from .compute_generator import create_solid_compute_wrapper
-from .utils import solid_execution_error_boundary
+from .utils import op_execution_error_boundary
 
 
 def _step_output_error_checked_user_event_sequence(
@@ -86,7 +85,7 @@ def _step_output_error_checked_user_event_sequence(
     This consumes and emits an event sequence.
     """
     check.inst_param(step_context, "step_context", StepExecutionContext)
-    check.generator_param(user_event_sequence, "user_event_sequence")
+    check.iterator_param(user_event_sequence, "user_event_sequence")
 
     step = step_context.step
     op_label = step_context.describe_op()
@@ -339,7 +338,7 @@ def core_dagster_event_sequence_for_step(
     inputs = {}
 
     if step_context.step_materializes_assets:
-        step_context.fetch_input_asset_records()
+        step_context.fetch_external_input_asset_records()
 
     for step_input in step_context.step.step_inputs:
         input_def = step_context.solid_def.input_def_named(step_input.name)
@@ -370,7 +369,7 @@ def core_dagster_event_sequence_for_step(
     # was generated from the @solid or @lambda_solid decorator, then compute_fn needs to be coerced
     # into this format. If the solid definition was created directly, then it is expected that the
     # compute_fn is already in this format.
-    if isinstance(step_context.solid_def.compute_fn, DecoratedSolidFunction):
+    if isinstance(step_context.solid_def.compute_fn, DecoratedOpFunction):
         core_gen = create_solid_compute_wrapper(step_context.solid_def)
     else:
         core_gen = step_context.solid_def.compute_fn
@@ -458,24 +457,11 @@ def _type_check_and_store_output(
 
 def _asset_key_and_partitions_for_output(
     output_context: OutputContext,
-    output_def: OutputDefinition,
-    output_manager: IOManager,
 ) -> Tuple[Optional[AssetKey], AbstractSet[str]]:
 
-    manager_asset_key = output_manager.get_output_asset_key(output_context)
-    node_handle = output_context.step_context.solid_handle
     output_asset_info = output_context.asset_info
 
     if output_asset_info:
-        if manager_asset_key is not None:
-            raise DagsterInvariantViolationError(
-                f'The IOManager of output "{output_def.name}" on node "{node_handle}" associates it '
-                f'with asset key "{manager_asset_key}", but this output has already been defined to '
-                f'produce asset "{output_asset_info.key}", either via a Software Defined Asset, '
-                "or by setting the asset_key parameter on the OutputDefinition. In most cases, this "
-                "means that you should use an IOManager that does not specify an AssetKey in its "
-                "get_output_asset_key() function for this output."
-            )
         if not output_asset_info.is_required:
             output_context.log.warn(f"Materializing unexpected asset key: {output_asset_info.key}.")
         return (
@@ -483,9 +469,6 @@ def _asset_key_and_partitions_for_output(
             output_asset_info.partitions_fn(output_context) or set(),
         )
 
-    if manager_asset_key:
-        return manager_asset_key, output_manager.get_output_asset_partitions(output_context)
-
     return None, set()
 
 
@@ -519,12 +502,20 @@ def _get_output_asset_materializations(
 
     all_metadata = [*output.metadata_entries, *io_manager_metadata_entries]
 
-    # If our asset key is generated by the IO manager, then it's not managed with logical versions.
-    tags: Dict[str, str] = (
-        _build_logical_version_tags(asset_key, step_context)
-        if step_context.input_asset_records is not None
-        else {}
-    )
+    # Clear any cached record associated with this asset, since we are about to generate a new
+    # materialization.
+    step_context.wipe_input_asset_record(asset_key)
+
+    tags: Dict[str, str]
+    if (
+        step_context.is_external_input_asset_records_loaded
+        and asset_key in step_context.pipeline_def.asset_layer.asset_keys
+    ):
+        tags = _build_logical_version_tags(asset_key, step_context)
+        logical_version = LogicalVersion(tags[LOGICAL_VERSION_TAG_KEY])
+        step_context.record_logical_version(asset_key, logical_version)
+    else:
+        tags = {}
 
     if asset_partitions:
         metadata_mapping: Dict[
@@ -583,12 +574,18 @@ def _build_logical_version_tags(
     asset_key: AssetKey, step_context: StepExecutionContext
 ) -> Dict[str, str]:
     asset_layer = step_context.pipeline_def.asset_layer
-    code_version = asset_layer.op_version_for_asset(asset_key) or step_context.pipeline_run.run_id
-    input_asset_records = check.not_none(step_context.input_asset_records)
+    code_version = asset_layer.code_version_for_asset(asset_key) or step_context.pipeline_run.run_id
     input_logical_versions: Dict[AssetKey, LogicalVersion] = {}
     tags: Dict[str, str] = {}
     tags[CODE_VERSION_TAG_KEY] = code_version
-    for key, event in input_asset_records.items():
+    deps = step_context.pipeline_def.asset_layer.upstream_assets_for_asset(asset_key)
+    for key in deps:
+        # For deps external to this step, this will retrieve the cached record that was stored prior
+        # to step execution. For inputs internal to this step, it may trigger a query to retrieve
+        # the most recent materialization record (it will retrieve a cached record if it's already
+        # been asked for). For this to be correct, the output materializations for the step must be
+        # generated in topological order -- we assume this.
+        event = step_context.get_input_asset_record(key)
         if event is not None:
             logical_version = (
                 extract_logical_version_from_entry(event.event_log_entry) or DEFAULT_LOGICAL_VERSION
@@ -637,7 +634,7 @@ def _store_output(
         handle_output_gen = output_manager.handle_output(output_context, output.value)
 
     for elt in iterate_with_context(
-        lambda: solid_execution_error_boundary(
+        lambda: op_execution_error_boundary(
             DagsterExecutionHandleOutputError,
             msg_fn=lambda: (
                 f'Error occurred while handling output "{output_context.name}" of '
@@ -693,9 +690,7 @@ def _store_output(
                 )
         yield DagsterEvent.asset_materialization(step_context, materialization, input_lineage)
 
-    asset_key, partitions = _asset_key_and_partitions_for_output(
-        output_context, output_def, output_manager
-    )
+    asset_key, partitions = _asset_key_and_partitions_for_output(output_context)
     if asset_key:
         for materialization in _get_output_asset_materializations(
             asset_key,
@@ -705,7 +700,11 @@ def _store_output(
             manager_metadata_entries,
             step_context,
         ):
-            yield DagsterEvent.asset_materialization(step_context, materialization, input_lineage)
+            yield DagsterEvent.asset_materialization(
+                step_context,
+                materialization,
+                input_lineage,
+            )
 
     yield DagsterEvent.handled_output(
         step_context,
