@@ -1,6 +1,6 @@
 import sys
 from contextlib import contextmanager
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, Iterator, Type
 
 import dagster._check as check
 from dagster._core.definitions.events import Failure, RetryRequested
@@ -25,8 +25,17 @@ def build_resources_for_manager(
     return step_context.scoped_resources_builder.build(required_resource_keys)
 
 
+class RetryRequestedFromPolicy(RetryRequested):
+    """Subclass to indicate origin of retry request is policy"""
+
+
 @contextmanager
-def solid_execution_error_boundary(error_cls, msg_fn, step_context, **kwargs):
+def op_execution_error_boundary(
+    error_cls: Type[DagsterUserCodeExecutionError],
+    msg_fn: Callable[[], str],
+    step_context: "StepExecutionContext",
+    **kwargs: Any,
+) -> Iterator[None]:
     """
     A specialization of user_code_error_boundary for the steps involved in executing a solid.
     This variant supports the control flow exceptions RetryRequested and Failure as well
@@ -62,7 +71,7 @@ def solid_execution_error_boundary(error_cls, msg_fn, step_context, **kwargs):
                 if isinstance(e, Failure) and not e.allow_retries:
                     raise e
 
-                raise RetryRequested(
+                raise RetryRequestedFromPolicy(
                     max_retries=retry_policy.max_retries,
                     seconds_to_wait=retry_policy.calculate_delay(
                         step_context.previous_attempt_count + 1
