@@ -13,9 +13,11 @@ from enum import Enum
 from tempfile import TemporaryDirectory
 from typing import (
     TYPE_CHECKING,
+    AbstractSet,
     Any,
     Callable,
     Dict,
+    FrozenSet,
     Generic,
     Iterable,
     List,
@@ -33,6 +35,7 @@ import yaml
 
 import dagster._check as check
 from dagster._annotations import public
+from dagster._config.field import Field
 from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.pipeline_base import InMemoryPipeline
 from dagster._core.definitions.pipeline_definition import (
@@ -49,10 +52,9 @@ from dagster._core.errors import (
 from dagster._core.storage.pipeline_run import (
     IN_PROGRESS_RUN_STATUSES,
     DagsterRun,
+    DagsterRunStatus,
     JobBucket,
-    PipelineRun,
     PipelineRunStatsSnapshot,
-    PipelineRunStatus,
     RunPartitionData,
     RunRecord,
     RunsFilter,
@@ -66,6 +68,7 @@ from dagster._seven import get_current_datetime_in_utc
 from dagster._utils import merge_dicts, traced
 from dagster._utils.backcompat import deprecation_warning, experimental_functionality_warning
 from dagster._utils.error import serializable_error_info_from_exc_info
+from dagster._utils.log import get_dagster_logger
 
 from .config import (
     DAGSTER_CONFIG_YAML_FILENAME,
@@ -90,6 +93,7 @@ if TYPE_CHECKING:
     from dagster._core.events import DagsterEvent, DagsterEventType
     from dagster._core.events.log import EventLogEntry
     from dagster._core.execution.backfill import PartitionBackfill
+    from dagster._core.execution.plan.plan import ExecutionPlan
     from dagster._core.execution.plan.resume_retry import ReexecutionStrategy
     from dagster._core.execution.stats import RunStepKeyStatsSnapshot
     from dagster._core.host_representation import (
@@ -98,6 +102,7 @@ if TYPE_CHECKING:
         HistoricalPipeline,
         RepositoryLocation,
     )
+    from dagster._core.host_representation.origin import ExternalPipelineOrigin
     from dagster._core.launcher import RunLauncher
     from dagster._core.run_coordinator import RunCoordinator
     from dagster._core.scheduler import Scheduler
@@ -121,7 +126,7 @@ if TYPE_CHECKING:
 
 
 def _check_run_equality(
-    pipeline_run: PipelineRun, candidate_run: PipelineRun
+    pipeline_run: DagsterRun, candidate_run: DagsterRun
 ) -> Mapping[str, Tuple[Any, Any]]:
     field_diff = {}
     for field in pipeline_run._fields:
@@ -167,7 +172,7 @@ class _EventListenerLogHandler(logging.Handler):
                 name=record.name,
                 message=record.msg,
                 level=record.levelno,
-                meta=record.dagster_meta,
+                meta=record.dagster_meta,  # type: ignore
                 record=record,
             )
         )
@@ -204,8 +209,10 @@ T_DagsterInstance = TypeVar("T_DagsterInstance", bound="DagsterInstance")
 class MayHaveInstanceWeakref(Generic[T_DagsterInstance]):
     """Mixin for classes that can have a weakref back to a Dagster instance."""
 
+    _instance_weakref: Optional[weakref.ReferenceType[T_DagsterInstance]]
+
     def __init__(self):
-        self._instance_weakref: Optional[weakref.ReferenceType[T_DagsterInstance]] = None
+        self._instance_weakref = None
 
     @property
     def _instance(self) -> T_DagsterInstance:
@@ -292,7 +299,7 @@ class DagsterInstance:
         event_storage: "EventLogStorage",
         compute_log_manager: "ComputeLogManager",
         run_coordinator: "RunCoordinator",
-        run_launcher: "RunLauncher",
+        run_launcher: Optional["RunLauncher"],
         scheduler: Optional["Scheduler"] = None,
         schedule_storage: Optional["ScheduleStorage"] = None,
         settings: Optional[Mapping[str, Any]] = None,
@@ -339,8 +346,14 @@ class DagsterInstance:
         self._run_coordinator = check.inst_param(run_coordinator, "run_coordinator", RunCoordinator)
         self._run_coordinator.register_instance(self)
 
-        self._run_launcher = check.inst_param(run_launcher, "run_launcher", RunLauncher)
-        self._run_launcher.register_instance(self)
+        if run_launcher:
+            self._run_launcher: Optional[RunLauncher] = check.inst_param(
+                run_launcher, "run_launcher", RunLauncher
+            )
+            run_launcher.register_instance(self)
+        else:
+            check.invariant(ref, "Run launcher must be provided if instance is not from a ref")
+            self._run_launcher = None
 
         self._settings = check.opt_mapping_param(settings, "settings")
 
@@ -493,7 +506,7 @@ class DagsterInstance:
             compute_log_manager=instance_ref.compute_log_manager,
             scheduler=instance_ref.scheduler,
             run_coordinator=instance_ref.run_coordinator,
-            run_launcher=instance_ref.run_launcher,
+            run_launcher=None,  # lazy load
             settings=instance_ref.settings,
             secrets_loader=instance_ref.secrets_loader,
             ref=instance_ref,
@@ -568,7 +581,7 @@ class DagsterInstance:
             "schedule_storage": self._info(self._schedule_storage),
             "scheduler": self._info(self._scheduler),
             "run_coordinator": self._info(self._run_coordinator),
-            "run_launcher": self._info(self._run_launcher),
+            "run_launcher": self._info(self.run_launcher),
         }
         ret.update(
             {
@@ -636,6 +649,16 @@ class DagsterInstance:
 
     @property
     def run_launcher(self) -> "RunLauncher":
+        from dagster._core.launcher import RunLauncher
+
+        # Lazily load in case the launcher requires dependencies that are not available everywhere
+        # that loads the instance (e.g. The EcsRunLauncher requires boto3)
+        if not self._run_launcher:
+            check.invariant(self._ref, "Run launcher not provided, and no instance ref available")
+            launcher = cast(InstanceRef, self._ref).run_launcher
+            check.invariant(launcher, "Run launcher not configured in instance ref")
+            self._run_launcher = cast(RunLauncher, launcher)
+            self._run_launcher.register_instance(self)
         return self._run_launcher
 
     # compute logs
@@ -748,7 +771,7 @@ class DagsterInstance:
             self._schedule_storage.upgrade()
             self._schedule_storage.migrate(print_fn)
 
-    def optimize_for_dagit(self, statement_timeout, pool_recycle):
+    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
         if self._schedule_storage:
             self._schedule_storage.optimize_for_dagit(
                 statement_timeout=statement_timeout, pool_recycle=pool_recycle
@@ -771,7 +794,8 @@ class DagsterInstance:
     def dispose(self):
         self._run_storage.dispose()
         self.run_coordinator.dispose()
-        self._run_launcher.dispose()
+        if self._run_launcher:
+            self._run_launcher.dispose()
         self._event_storage.dispose()
         self._compute_log_manager.dispose()
         if self._secrets_loader:
@@ -828,27 +852,27 @@ class DagsterInstance:
         return self._run_storage.get_run_tags()
 
     @traced
-    def get_run_group(self, run_id: str) -> Optional[Tuple[str, Iterable[PipelineRun]]]:
+    def get_run_group(self, run_id: str) -> Optional[Tuple[str, Iterable[DagsterRun]]]:
         return self._run_storage.get_run_group(run_id)
 
     def create_run_for_pipeline(
         self,
-        pipeline_def,
-        execution_plan=None,
-        run_id=None,
-        run_config=None,
-        mode=None,
-        solids_to_execute=None,
-        status=None,
-        tags=None,
-        root_run_id=None,
-        parent_run_id=None,
-        solid_selection=None,
-        asset_selection=None,
+        pipeline_def: PipelineDefinition,
+        execution_plan: Optional["ExecutionPlan"] = None,
+        run_id: Optional[str] = None,
+        run_config: Optional[Mapping[str, object]] = None,
+        mode: Optional[str] = None,
+        solids_to_execute: Optional[AbstractSet[str]] = None,
+        status: Optional[str] = None,
+        tags: Optional[Mapping[str, str]] = None,
+        root_run_id: Optional[str] = None,
+        parent_run_id: Optional[str] = None,
+        solid_selection: Optional[Sequence[str]] = None,
+        asset_selection: Optional[FrozenSet[AssetKey]] = None,
         external_pipeline_origin=None,
         pipeline_code_origin=None,
         repository_load_data=None,
-    ) -> PipelineRun:
+    ) -> DagsterRun:
         from dagster._core.definitions.job_definition import JobDefinition
         from dagster._core.execution.api import create_execution_plan
         from dagster._core.execution.plan.plan import ExecutionPlan
@@ -1104,7 +1128,7 @@ class DagsterInstance:
         solid_selection=None,
         external_pipeline_origin=None,
         pipeline_code_origin=None,
-    ) -> PipelineRun:
+    ) -> DagsterRun:
 
         pipeline_run = self._construct_run_with_snapshots(
             pipeline_name=pipeline_name,
@@ -1143,7 +1167,7 @@ class DagsterInstance:
         run_config: Optional[Mapping[str, Any]] = None,
         mode: Optional[str] = None,
         use_parent_run_tags: bool = False,
-    ) -> PipelineRun:
+    ) -> DagsterRun:
         from dagster._core.execution.plan.resume_retry import (
             ReexecutionStrategy,
             get_retry_steps_from_parent_run,
@@ -1179,7 +1203,7 @@ class DagsterInstance:
 
         if strategy == ReexecutionStrategy.FROM_FAILURE:
             check.invariant(
-                parent_run.status == PipelineRunStatus.FAILURE,
+                parent_run.status == DagsterRunStatus.FAILURE,
                 "Cannot reexecute from failure a run that is not failed",
             )
 
@@ -1210,7 +1234,7 @@ class DagsterInstance:
             mode=mode,
             solids_to_execute=parent_run.solids_to_execute,
             step_keys_to_execute=step_keys_to_execute,
-            status=PipelineRunStatus.NOT_STARTED,
+            status=DagsterRunStatus.NOT_STARTED,
             tags=tags,
             root_run_id=root_run_id,
             parent_run_id=parent_run_id,
@@ -1259,7 +1283,7 @@ class DagsterInstance:
             solid_selection=solid_selection,
             solids_to_execute=solids_to_execute,
             step_keys_to_execute=step_keys_to_execute,
-            status=PipelineRunStatus.MANAGED,
+            status=DagsterRunStatus.MANAGED,
             tags=tags,
             root_run_id=root_run_id,
             parent_run_id=parent_run_id,
@@ -1293,7 +1317,7 @@ class DagsterInstance:
             return get_run()
 
     @traced
-    def add_run(self, pipeline_run: PipelineRun) -> PipelineRun:
+    def add_run(self, pipeline_run: DagsterRun) -> DagsterRun:
         return self._run_storage.add_run(pipeline_run)
 
     @traced
@@ -1319,7 +1343,7 @@ class DagsterInstance:
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
         bucket_by: Optional[Union[JobBucket, TagBucket]] = None,
-    ) -> Iterable[PipelineRun]:
+    ) -> Iterable[DagsterRun]:
         return self._run_storage.get_runs(filters, cursor, limit, bucket_by)
 
     @traced
@@ -1332,7 +1356,7 @@ class DagsterInstance:
         filters: Optional[RunsFilter] = None,
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
-    ) -> Mapping[str, Mapping[str, Union[Iterable[PipelineRun], int]]]:
+    ) -> Mapping[str, Mapping[str, Union[Iterable[DagsterRun], int]]]:
         return self._run_storage.get_run_groups(filters=filters, cursor=cursor, limit=limit)
 
     @public
@@ -1385,8 +1409,8 @@ class DagsterInstance:
     @traced
     def logs_after(
         self,
-        run_id,
-        cursor,
+        run_id: str,
+        cursor: Optional[int] = None,
         of_type: Optional["DagsterEventType"] = None,
         limit: Optional[int] = None,
     ):
@@ -1477,7 +1501,10 @@ class DagsterInstance:
 
     @traced
     def get_event_tags_for_asset(
-        self, asset_key: AssetKey, filter_tags: Optional[Mapping[str, str]] = None
+        self,
+        asset_key: AssetKey,
+        filter_tags: Optional[Mapping[str, str]] = None,
+        filter_event_id: Optional[int] = None,
     ) -> Sequence[Mapping[str, str]]:
         """
         Fetches asset event tags for the given asset key.
@@ -1487,10 +1514,12 @@ class DagsterInstance:
         partition tags with a fixed dimension value, e.g. all of the tags for events where
         "country" == "US".
 
+        If filter_event_id is provided, searches for the event with the provided event_id.
+
         Returns a list of dicts, where each dict is a mapping of tag key to tag value for a
         single event.
         """
-        return self._event_storage.get_event_tags_for_asset(asset_key, filter_tags)
+        return self._event_storage.get_event_tags_for_asset(asset_key, filter_tags, filter_event_id)
 
     @traced
     def run_ids_for_asset_key(self, asset_key):
@@ -1499,7 +1528,7 @@ class DagsterInstance:
 
     @public
     @traced
-    def wipe_assets(self, asset_keys):
+    def wipe_assets(self, asset_keys: Sequence[AssetKey]):
         check.list_param(asset_keys, "asset_keys", of_type=AssetKey)
         for asset_key in asset_keys:
             self._event_storage.wipe_asset(asset_key)
@@ -1583,7 +1612,7 @@ class DagsterInstance:
 
         check.opt_class_param(cls, "cls")
         check.str_param(message, "message")
-        check.opt_inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.opt_inst_param(pipeline_run, "pipeline_run", DagsterRun)
         check.opt_str_param(run_id, "run_id")
         check.opt_str_param(pipeline_name, "pipeline_name")
 
@@ -1646,7 +1675,7 @@ class DagsterInstance:
 
         from dagster._core.events import DagsterEvent, DagsterEventType
 
-        check.inst_param(run, "run", PipelineRun)
+        check.inst_param(run, "run", DagsterRun)
         message = check.opt_str_param(
             message,
             "message",
@@ -1666,7 +1695,7 @@ class DagsterInstance:
     ):
         from dagster._core.events import DagsterEvent, DagsterEventType
 
-        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
 
         message = check.opt_str_param(
             message,
@@ -1687,7 +1716,7 @@ class DagsterInstance:
     def report_run_failed(self, pipeline_run, message=None):
         from dagster._core.events import DagsterEvent, DagsterEventType
 
-        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
 
         message = check.opt_str_param(
             message,
@@ -1707,7 +1736,7 @@ class DagsterInstance:
 
     # directories
 
-    def file_manager_directory(self, run_id):
+    def file_manager_directory(self, run_id: str):
         return self._local_artifact_storage.file_manager_dir(run_id)
 
     def storage_directory(self):
@@ -1718,7 +1747,7 @@ class DagsterInstance:
 
     # Runs coordinator
 
-    def submit_run(self, run_id, workspace: "IWorkspace") -> PipelineRun:
+    def submit_run(self, run_id, workspace: "IWorkspace") -> DagsterRun:
         """Submit a pipeline run to the coordinator.
 
         This method delegates to the ``RunCoordinator``, configured on the instance, and will
@@ -1807,7 +1836,7 @@ class DagsterInstance:
             check.failed(f"Failed to reload run {run_id}")
 
         try:
-            self._run_launcher.launch_run(LaunchRunContext(pipeline_run=run, workspace=workspace))
+            self.run_launcher.launch_run(LaunchRunContext(pipeline_run=run, workspace=workspace))
         except:
             error = serializable_error_info_from_exc_info(sys.exc_info())
             self.report_engine_event(
@@ -1849,7 +1878,7 @@ class DagsterInstance:
         )
 
         try:
-            self._run_launcher.resume_run(
+            self.run_launcher.resume_run(
                 ResumeRunContext(
                     pipeline_run=run,
                     workspace=workspace,
