@@ -1,6 +1,6 @@
 from enum import Enum
 from inspect import Parameter
-from typing import Any, Dict, Mapping, NamedTuple, Optional, Sequence, Type, Union
+from typing import Any, Dict, List, Mapping, NamedTuple, Optional, Sequence, Type, Union
 
 import dagster._check as check
 from dagster._core.definitions.run_request import InstigatorType
@@ -343,6 +343,9 @@ class InstigatorTick(NamedTuple("_InstigatorTick", [("tick_id", int), ("tick_dat
     def with_origin_run(self, origin_run_id):
         return self._replace(tick_data=self.tick_data.with_origin_run(origin_run_id))
 
+    def with_log_key(self, log_key):
+        return self._replace(tick_data=self.tick_data.with_log_key(log_key))
+
     @property
     def instigator_origin_id(self):
         return self.tick_data.instigator_origin_id
@@ -395,6 +398,10 @@ class InstigatorTick(NamedTuple("_InstigatorTick", [("tick_id", int), ("tick_dat
     def failure_count(self) -> int:
         return self.tick_data.failure_count
 
+    @property
+    def log_key(self) -> Optional[List[str]]:
+        return self.tick_data.log_key
+
 
 register_serdes_tuple_fallbacks({"JobTick": InstigatorTick})
 # for internal backcompat
@@ -468,6 +475,7 @@ class TickData(
             ("origin_run_ids", Sequence[str]),
             ("failure_count", int),
             ("selector_id", Optional[str]),
+            ("log_key", Optional[List[str]]),
         ],
     )
 ):
@@ -506,8 +514,10 @@ class TickData(
         origin_run_ids: Optional[Sequence[str]] = None,
         failure_count: Optional[int] = None,
         selector_id: Optional[str] = None,
+        log_key: Optional[List[str]] = None,
     ):
         _validate_tick_args(instigator_type, status, run_ids, error, skip_reason)
+        check.opt_list_param(log_key, "log_key", of_type=str)
         return super(TickData, cls).__new__(
             cls,
             check.str_param(instigator_origin_id, "instigator_origin_id"),
@@ -523,6 +533,7 @@ class TickData(
             origin_run_ids=check.opt_sequence_param(origin_run_ids, "origin_run_ids", of_type=str),
             failure_count=check.opt_int_param(failure_count, "failure_count", 0),
             selector_id=check.opt_str_param(selector_id, "selector_id"),
+            log_key=log_key,
         )
 
     def with_status(self, status, error=None, timestamp=None, failure_count=None):
@@ -592,6 +603,14 @@ class TickData(
             )
         )
 
+    def with_log_key(self, log_key):
+        return TickData(
+            **merge_dicts(
+                self._asdict(),
+                {"log_key": check.list_param(log_key, "log_key", of_type=str)},
+            )
+        )
+
 
 register_serdes_tuple_fallbacks({"JobTickData": TickData})
 # for internal backcompat
