@@ -10,7 +10,7 @@ from watchdog.observers import Observer
 import dagster._check as check
 from dagster._config import StringSource
 from dagster._core.storage.event_log.base import EventLogCursor
-from dagster._core.storage.pipeline_run import PipelineRunStatus
+from dagster._core.storage.pipeline_run import DagsterRunStatus
 from dagster._core.storage.sql import (
     check_alembic_revision,
     create_engine,
@@ -169,9 +169,9 @@ class ConsolidatedSqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                     logging.exception("Exception in callback for event watch on run %s.", run_id)
 
                 if (
-                    status == PipelineRunStatus.SUCCESS
-                    or status == PipelineRunStatus.FAILURE
-                    or status == PipelineRunStatus.CANCELED
+                    status == DagsterRunStatus.SUCCESS
+                    or status == DagsterRunStatus.FAILURE
+                    or status == DagsterRunStatus.CANCELED
                 ):
                     self.end_watch(run_id, callback)
 
