@@ -17,6 +17,7 @@ from dagster import Permissive, Shape
 from dagster import _check as check
 from dagster import fs_io_manager
 from dagster._config import Array, Field
+from dagster._core.definitions.decorators.graph_decorator import graph
 from dagster._core.host_representation.origin import (
     ExternalPipelineOrigin,
     InProcessRepositoryLocationOrigin,
@@ -25,11 +26,11 @@ from dagster._core.instance import DagsterInstance
 from dagster._core.launcher import RunLauncher
 from dagster._core.run_coordinator import RunCoordinator, SubmitRunContext
 from dagster._core.secrets import SecretsLoader
-from dagster._core.storage.pipeline_run import PipelineRun, PipelineRunStatus, RunsFilter
+from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus, RunsFilter
 from dagster._core.workspace.context import WorkspaceProcessContext
 from dagster._core.workspace.load_target import WorkspaceLoadTarget
 from dagster._daemon.controller import create_daemon_grpc_server_registry
-from dagster._legacy import ModeDefinition, composite_solid, pipeline, solid
+from dagster._legacy import ModeDefinition, pipeline, solid
 from dagster._serdes import ConfigurableClass
 from dagster._seven.compat.pendulum import create_pendulum_time, mock_pendulum_timezone
 from dagster._utils import Counter, merge_dicts, traced, traced_counter
@@ -63,7 +64,7 @@ def step_output_event_filter(pipe_iterator):
             yield step_event
 
 
-def nesting_composite_pipeline(depth, num_children, *args, **kwargs):
+def nesting_graph_pipeline(depth, num_children, *args, **kwargs):
     """Creates a pipeline of nested composite solids up to "depth" layers, with a fan-out of
     num_children at each layer.
 
@@ -75,7 +76,7 @@ def nesting_composite_pipeline(depth, num_children, *args, **kwargs):
         return 1
 
     def create_wrap(inner, name):
-        @composite_solid(name=name)
+        @graph(name=name)
         def wrap():
             for i in range(num_children):
                 solid_alias = "%s_node_%d" % (name, i)
@@ -167,7 +168,10 @@ def cleanup_test_instance(instance):
     # To avoid filesystem contention when we close the temporary directory, wait for
     # all runs to reach a terminal state, and close any subprocesses or threads
     # that might be accessing the run history DB.
-    instance.run_launcher.join()
+
+    # Since launcher is lazy loaded, we don't need to do anyting if it's None
+    if instance._run_launcher:  # pylint: disable=protected-access
+        instance._run_launcher.join()  # pylint: disable=protected-access
 
 
 TEST_PIPELINE_NAME = "_test_pipeline_"
@@ -268,9 +272,9 @@ def poll_for_finished_run(instance, run_id=None, timeout=20, run_tags=None):
         run_ids=[run_id] if run_id else None,
         tags=run_tags,
         statuses=[
-            PipelineRunStatus.SUCCESS,
-            PipelineRunStatus.FAILURE,
-            PipelineRunStatus.CANCELED,
+            DagsterRunStatus.SUCCESS,
+            DagsterRunStatus.FAILURE,
+            DagsterRunStatus.CANCELED,
         ],
     )
 
@@ -370,8 +374,8 @@ class MockedRunLauncher(RunLauncher, ConfigurableClass):
 
     def launch_run(self, context):
         run = context.pipeline_run
-        check.inst_param(run, "run", PipelineRun)
-        check.invariant(run.status == PipelineRunStatus.STARTING)
+        check.inst_param(run, "run", DagsterRun)
+        check.invariant(run.status == DagsterRunStatus.STARTING)
 
         if self._bad_run_ids and run.run_id in self._bad_run_ids:
             raise Exception(f"Bad run {run.run_id}")
