@@ -30,7 +30,7 @@ from dagster._core.scheduler.instigation import (
     TickData,
     TickStatus,
 )
-from dagster._core.storage.pipeline_run import PipelineRun, PipelineRunStatus, RunsFilter
+from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus, RunsFilter
 from dagster._core.storage.tags import RUN_KEY_TAG, SENSOR_NAME_TAG
 from dagster._core.telemetry import SENSOR_RUN_CREATED, hash_name, log_action
 from dagster._core.workspace.context import IWorkspaceProcessContext
@@ -53,7 +53,7 @@ class SkippedSensorRun(
         "SkippedSensorRun",
         [
             ("run_key", Optional[str]),
-            ("existing_run", PipelineRun),
+            ("existing_run", DagsterRun),
         ],
     )
 ):
@@ -122,6 +122,9 @@ class SensorLaunchContext:
     def add_run_info(self, run_id=None, run_key=None):
         self._tick = self._tick.with_run_info(run_id, run_key)
 
+    def add_log_info(self, log_key):
+        self._tick = self._tick.with_log_key(log_key)
+
     def set_should_update_cursor_on_failure(self, should_update_cursor_on_failure: bool):
         self._should_update_cursor_on_failure = should_update_cursor_on_failure
 
@@ -551,6 +554,9 @@ def _evaluate_sensor(
 
     yield
 
+    if sensor_runtime_data.captured_log_key:
+        context.add_log_info(sensor_runtime_data.captured_log_key)
+
     assert isinstance(sensor_runtime_data, SensorExecutionData)
     if not sensor_runtime_data.run_requests:
         if sensor_runtime_data.pipeline_run_reactions:
@@ -717,7 +723,7 @@ def _fetch_existing_runs(
     runs_with_run_keys = instance.get_runs(filters=RunsFilter(tags={RUN_KEY_TAG: run_keys}))
 
     # filter down to runs with run_key that match the sensor name and its namespace (repository)
-    valid_runs: List[PipelineRun] = []
+    valid_runs: List[DagsterRun] = []
     for run in runs_with_run_keys:
         # if the run doesn't have a set origin, just match on sensor name
         if (
@@ -751,7 +757,7 @@ def _get_or_create_sensor_run(
     external_pipeline: ExternalPipeline,
     run_request: RunRequest,
     target_data: ExternalTargetData,
-    existing_runs_by_key: Mapping[str, PipelineRun],
+    existing_runs_by_key: Mapping[str, DagsterRun],
 ):
 
     if not run_request.run_key:
@@ -762,7 +768,7 @@ def _get_or_create_sensor_run(
     run = existing_runs_by_key.get(run_request.run_key)
 
     if run:
-        if run.status != PipelineRunStatus.NOT_STARTED:
+        if run.status != DagsterRunStatus.NOT_STARTED:
             # A run already exists and was launched for this run key, but the daemon must have
             # crashed before the tick could be updated
             return SkippedSensorRun(run_key=run_request.run_key, existing_run=run)
@@ -803,7 +809,7 @@ def _create_sensor_run(
     pipeline_tags = validate_tags(external_pipeline.tags or {}, allow_reserved_tags=False)
     tags = merge_dicts(
         merge_dicts(pipeline_tags, run_request.tags),
-        PipelineRun.tags_for_sensor(external_sensor),
+        DagsterRun.tags_for_sensor(external_sensor),
     )
     if run_request.run_key:
         tags[RUN_KEY_TAG] = run_request.run_key
@@ -826,7 +832,7 @@ def _create_sensor_run(
         mode=target_data.mode,
         solids_to_execute=external_pipeline.solids_to_execute,
         step_keys_to_execute=None,
-        status=PipelineRunStatus.NOT_STARTED,
+        status=DagsterRunStatus.NOT_STARTED,
         solid_selection=target_data.solid_selection,
         root_run_id=None,
         parent_run_id=None,
