@@ -39,13 +39,9 @@ from dagster._core.definitions import (
     lambda_solid,
 )
 from dagster._core.definitions.logger_definition import LoggerDefinition
+from dagster._core.definitions.node_definition import NodeDefinition
 from dagster._core.definitions.pipeline_base import InMemoryPipeline
 from dagster._core.definitions.resource_definition import ScopedResourcesBuilder
-from dagster._core.definitions.solid_definition import (
-    CompositeSolidDefinition,
-    NodeDefinition,
-    SolidDefinition,
-)
 from dagster._core.execution.api import (
     create_execution_plan,
     execute_pipeline,
@@ -65,8 +61,8 @@ from dagster._core.scheduler import Scheduler
 from dagster._core.scheduler.scheduler import DagsterScheduleDoesNotExist, DagsterSchedulerError
 from dagster._core.snap import snapshot_from_execution_plan
 from dagster._core.storage.file_manager import LocalFileManager
-from dagster._core.storage.pipeline_run import PipelineRun
-from dagster._core.types.dagster_type import resolve_dagster_type
+from dagster._core.storage.pipeline_run import DagsterRun
+from dagster._core.types.dagster_type import DagsterType, resolve_dagster_type
 from dagster._core.utility_solids import define_stub_solid
 from dagster._core.utils import make_new_run_id
 from dagster._serdes import ConfigurableClass
@@ -83,7 +79,7 @@ from ..temp_file import (
 from ..typing_api import is_typing_type
 
 if TYPE_CHECKING:
-    from dagster._core.execution.results import CompositeSolidExecutionResult, SolidExecutionResult
+    from dagster._core.execution.results import CompositeSolidExecutionResult, OpExecutionResult
 
 
 def create_test_pipeline_execution_context(
@@ -97,7 +93,7 @@ def create_test_pipeline_execution_context(
         name="test_legacy_context", solid_defs=[], mode_defs=[mode_def]
     )
     run_config: Dict[str, Dict[str, Dict]] = {"loggers": {key: {} for key in loggers}}
-    pipeline_run = PipelineRun(pipeline_name="test_legacy_context", run_config=run_config)
+    pipeline_run = DagsterRun(pipeline_name="test_legacy_context", run_config=run_config)
     instance = DagsterInstance.ephemeral()
     execution_plan = create_execution_plan(pipeline=pipeline_def, run_config=run_config)
     creation_data = create_context_creation_data(
@@ -127,7 +123,7 @@ def _dep_key_of(solid):
 
 
 def build_pipeline_with_input_stubs(
-    pipeline_def: PipelineDefinition, inputs: Mapping[str, dict]
+    pipeline_def: PipelineDefinition, inputs: Mapping[str, Mapping[str, object]]
 ) -> PipelineDefinition:
     check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
     check.mapping_param(inputs, "inputs", key_type=str, value_type=dict)
@@ -170,13 +166,13 @@ def build_pipeline_with_input_stubs(
 def execute_solids_within_pipeline(
     pipeline_def: PipelineDefinition,
     solid_names: AbstractSet[str],
-    inputs: Optional[Mapping[str, dict]] = None,
+    inputs: Optional[Mapping[str, Mapping[str, object]]] = None,
     run_config: Optional[Mapping[str, object]] = None,
     mode: Optional[str] = None,
     preset: Optional[str] = None,
     tags: Optional[Mapping[str, str]] = None,
     instance: Optional[DagsterInstance] = None,
-) -> Mapping[str, Union["CompositeSolidExecutionResult", "SolidExecutionResult"]]:
+) -> Mapping[str, Union["CompositeSolidExecutionResult", "OpExecutionResult"]]:
     """Execute a set of solids within an existing pipeline.
 
     Intended to support tests. Input values may be passed directly.
@@ -221,34 +217,44 @@ def execute_solids_within_pipeline(
 
 
 def wrap_op_in_graph(
-    op_def: OpDefinition, tags: Optional[Mapping[str, Any]] = None
+    op_def: OpDefinition,
+    tags: Optional[Mapping[str, Any]] = None,
+    do_input_mapping: bool = True,
+    do_output_mapping: bool = True,
 ) -> GraphDefinition:
     """Wraps op in a graph with the same inputs/outputs as the original op."""
     check.inst_param(op_def, "op_def", OpDefinition)
     check.opt_mapping_param(tags, "tags", key_type=str)
 
-    input_mappings = []
-    for input_name in op_def.ins.keys():
-        # create an input mapping to the inner node with the same name.
-        input_mappings.append(
-            InputMapping(
-                graph_input_name=input_name,
-                mapped_node_name=op_def.name,
-                mapped_node_input_name=input_name,
+    if do_input_mapping:
+        input_mappings = []
+        for input_name in op_def.ins.keys():
+            # create an input mapping to the inner node with the same name.
+            input_mappings.append(
+                InputMapping(
+                    graph_input_name=input_name,
+                    mapped_node_name=op_def.name,
+                    mapped_node_input_name=input_name,
+                )
             )
-        )
+    else:
+        input_mappings = None
 
-    output_mappings = []
-    for output_name in op_def.outs.keys():
-        out = op_def.outs[output_name]
-        output_mappings.append(
-            OutputMapping(
-                graph_output_name=output_name,
-                mapped_node_name=op_def.name,
-                mapped_node_output_name=output_name,
-                from_dynamic_mapping=out.is_dynamic,
+    if do_output_mapping:
+        output_mappings = []
+        for output_name in op_def.outs.keys():
+            out = op_def.outs[output_name]
+            output_mappings.append(
+                OutputMapping(
+                    graph_output_name=output_name,
+                    mapped_node_name=op_def.name,
+                    mapped_node_output_name=output_name,
+                    from_dynamic_mapping=out.is_dynamic,
+                )
             )
-        )
+    else:
+        output_mappings = None
+
     return GraphDefinition(
         name=f"wraps_{op_def.name}",
         node_defs=[op_def],
@@ -265,10 +271,14 @@ def wrap_op_in_graph_and_execute(
     tags: Optional[Mapping[str, Any]] = None,
     run_config: Optional[Mapping[str, object]] = None,
     raise_on_error: bool = True,
+    do_input_mapping: bool = True,
+    do_output_mapping: bool = True,
 ) -> ExecuteInProcessResult:
     """Run a dagster op in an actual execution.
     For internal use."""
-    return wrap_op_in_graph(op_def, tags).execute_in_process(
+    return wrap_op_in_graph(
+        op_def, tags, do_input_mapping=do_input_mapping, do_output_mapping=do_output_mapping
+    ).execute_in_process(
         resources=resources,
         input_values=input_values,
         raise_on_error=raise_on_error,
@@ -277,15 +287,16 @@ def wrap_op_in_graph_and_execute(
 
 
 def execute_solid_within_pipeline(
-    pipeline_def,
-    solid_name,
-    inputs=None,
-    run_config=None,
-    mode=None,
-    preset=None,
-    tags=None,
-    instance=None,
-):
+    pipeline_def: PipelineDefinition,
+    solid_name: str,
+    inputs: Optional[Dict[str, object]] = None,
+    run_config: Optional[Dict[str, object]] = None,
+    mode: Optional[str] = None,
+    preset: Optional[str] = None,
+    tags: Optional[Dict[str, str]] = None,
+    instance: Optional[DagsterInstance] = None,
+) -> Union["CompositeSolidExecutionResult", "OpExecutionResult"]:
+
     """Execute a single solid within an existing pipeline.
 
     Intended to support tests. Input values may be passed directly.
@@ -326,7 +337,7 @@ def execute_solid_within_pipeline(
 
 @overload
 def execute_solid(
-    solid_def: CompositeSolidDefinition,
+    solid_def: GraphDefinition,
     mode_def: Optional[ModeDefinition] = ...,
     input_values: Optional[Mapping[str, object]] = ...,
     tags: Optional[Mapping[str, Any]] = ...,
@@ -338,13 +349,13 @@ def execute_solid(
 
 @overload
 def execute_solid(
-    solid_def: SolidDefinition,
+    solid_def: OpDefinition,
     mode_def: Optional[ModeDefinition] = ...,
     input_values: Optional[Mapping[str, object]] = ...,
     tags: Optional[Mapping[str, Any]] = ...,
     run_config: Optional[Mapping[str, object]] = ...,
     raise_on_error: bool = ...,
-) -> "SolidExecutionResult":
+) -> "OpExecutionResult":
     ...
 
 
@@ -355,7 +366,7 @@ def execute_solid(
     tags: Optional[Mapping[str, Any]] = None,
     run_config: Optional[Mapping[str, object]] = None,
     raise_on_error: bool = True,
-) -> Union["CompositeSolidExecutionResult", "SolidExecutionResult"]:
+) -> Union["CompositeSolidExecutionResult", "OpExecutionResult"]:
     """Execute a single solid in an ephemeral pipeline.
 
     Intended to support unit tests. Input values may be passed directly, and no pipeline need be
