@@ -1,6 +1,6 @@
 import functools
 import glob
-from typing import Any, Dict, Mapping, Sequence
+from typing import Any, Dict, List, Mapping, Sequence, Type
 
 import yaml
 
@@ -54,14 +54,18 @@ DagsterRunConfigYamlDumper.remove_implicit_resolver(YAML_TIMESTAMP_TAG)
 DagsterRunConfigYamlDumper.add_representer(str, _octal_string_representer)
 
 
-def load_yaml_from_globs(*globs: str, loader=DagsterRunConfigYamlLoader) -> object:
+def load_yaml_from_globs(
+    *globs: str, loader: Type[yaml.SafeLoader] = DagsterRunConfigYamlLoader
+) -> Mapping[object, object]:
     return load_yaml_from_glob_list(list(globs), loader=loader)
 
 
-def load_yaml_from_glob_list(glob_list: Sequence[str], loader=DagsterRunConfigYamlLoader) -> object:
+def load_yaml_from_glob_list(
+    glob_list: Sequence[str], loader: Type[yaml.SafeLoader] = DagsterRunConfigYamlLoader
+) -> Mapping[object, object]:
     check.sequence_param(glob_list, "glob_list", of_type=str)
 
-    all_files_list = []
+    all_files_list: List[str] = []
 
     for env_file_pattern in glob_list:
         all_files_list.extend(glob.glob(env_file_pattern))
@@ -69,7 +73,9 @@ def load_yaml_from_glob_list(glob_list: Sequence[str], loader=DagsterRunConfigYa
     return merge_yamls(all_files_list, loader=loader)
 
 
-def merge_yamls(file_list: Sequence[str], loader=DagsterRunConfigYamlLoader) -> Dict[str, Any]:
+def merge_yamls(
+    file_list: Sequence[str], loader: Type[yaml.SafeLoader] = DagsterRunConfigYamlLoader
+) -> Dict[object, object]:
     """Combine a list of YAML files into a dictionary.
 
     Args:
@@ -83,7 +89,7 @@ def merge_yamls(file_list: Sequence[str], loader=DagsterRunConfigYamlLoader) ->
     """
     check.sequence_param(file_list, "file_list", of_type=str)
 
-    merged: Dict[str, Any] = {}
+    merged: Dict[object, object] = {}
 
     for yaml_file in file_list:
         yaml_dict = load_yaml_from_path(yaml_file, loader=loader) or {}
@@ -100,7 +106,9 @@ def merge_yamls(file_list: Sequence[str], loader=DagsterRunConfigYamlLoader) ->
     return merged
 
 
-def merge_yaml_strings(yaml_strs: Sequence[str], loader=DagsterRunConfigYamlLoader) -> Mapping:
+def merge_yaml_strings(
+    yaml_strs: Sequence[str], loader: Type[yaml.SafeLoader] = DagsterRunConfigYamlLoader
+) -> Dict[object, object]:
     """Combine a list of YAML strings into a dictionary.  Right-most overrides left-most.
 
     Args:
@@ -126,7 +134,9 @@ def merge_yaml_strings(yaml_strs: Sequence[str], loader=DagsterRunConfigYamlLoad
     return functools.reduce(deep_merge_dicts, yaml_dicts, {})
 
 
-def load_yaml_from_path(path: str, loader=DagsterRunConfigYamlLoader) -> object:
+def load_yaml_from_path(
+    path: str, loader: Type[yaml.SafeLoader] = DagsterRunConfigYamlLoader
+) -> object:
     check.str_param(path, "path")
     with open(path, "r", encoding="utf8") as ff:
         return yaml.load(ff, Loader=loader)
